=== modified file 'Makefile'
--- Makefile	2011-05-08 17:58:08 +0000
+++ Makefile	2011-04-18 00:44:08 +0000
@@ -420,26 +420,6 @@
 	$(PYTHON) tools/win32/ostools.py remove dist
 
 
-# i18n targets
-
-.PHONY: update-pot po/bzr.pot
-update-pot: po/bzr.pot
-
-TRANSLATABLE_PYFILES:=$(shell find bzrlib -name '*.py' \
-    		| grep -v 'bzrlib/tests/' \
-    		| grep -v 'bzrlib/doc' \
-		)
-
-po/bzr.pot: $(PYFILES) $(DOCFILES)
-	$(PYTHON) ./bzr export-pot > po/bzr.pot
-	echo $(TRANSLATABLE_PYFILES) | xargs \
-	  xgettext --package-name "bzr" \
-	  --msgid-bugs-address "<bazaar@canonical.com>" \
-	  --copyright-holder "Canonical" \
-	  --from-code ISO-8859-1 --join --sort-by-file --add-comments=i18n: \
-	  -d bzr -p po -o bzr.pot
-
-
 ### Packaging Targets ###
 
 .PHONY: dist check-dist-tarball

=== modified file 'bzrlib/annotate.py'
--- bzrlib/annotate.py	2011-05-03 15:04:00 +0000
+++ bzrlib/annotate.py	2010-06-17 09:23:19 +0000
@@ -41,17 +41,9 @@
     )
 from bzrlib.config import extract_email_address
 from bzrlib.repository import _strip_NULL_ghosts
-from bzrlib.revision import (
-    CURRENT_REVISION,
-    Revision,
-    )
-from bzrlib.symbol_versioning import (
-    deprecated_function,
-    deprecated_in,
-    )
-
-
-@deprecated_function(deprecated_in((2, 4, 0)))
+from bzrlib.revision import CURRENT_REVISION, Revision
+
+
 def annotate_file(branch, rev_id, file_id, verbose=False, full=False,
                   to_file=None, show_ids=False):
     """Annotate file_id at revision rev_id in branch.
@@ -68,13 +60,21 @@
         used.
     :param show_ids: Show revision ids in the annotation output.
     """
-    tree = branch.repository.revision_tree(rev_id)
-    annotate_file_tree(tree, file_id, to_file, verbose=verbose,
-        full=full, show_ids=show_ids, branch=branch)
+    if to_file is None:
+        to_file = sys.stdout
+
+    # Handle the show_ids case
+    annotations = _annotations(branch.repository, file_id, rev_id)
+    if show_ids:
+        return _show_id_annotations(annotations, to_file, full)
+
+    # Calculate the lengths of the various columns
+    annotation = list(_expand_annotations(annotations, branch))
+    _print_annotations(annotation, verbose, to_file, full)
 
 
 def annotate_file_tree(tree, file_id, to_file, verbose=False, full=False,
-    show_ids=False, branch=None):
+    show_ids=False):
     """Annotate file_id in a tree.
 
     The tree should already be read_locked() when annotate_file_tree is called.
@@ -86,31 +86,25 @@
         reasonable text width.
     :param full: XXXX Not sure what this does.
     :param show_ids: Show revision ids in the annotation output.
-    :param branch: Branch to use for revision revno lookups
     """
-    if branch is None:
-        branch = tree.branch
-    if to_file is None:
-        to_file = sys.stdout
+    rev_id = tree.last_revision()
+    branch = tree.branch
 
     # Handle the show_ids case
     annotations = list(tree.annotate_iter(file_id))
     if show_ids:
         return _show_id_annotations(annotations, to_file, full)
 
-    if not getattr(tree, "get_revision_id", False):
-        # Create a virtual revision to represent the current tree state.
-        # Should get some more pending commit attributes, like pending tags,
-        # bugfixes etc.
-        current_rev = Revision(CURRENT_REVISION)
-        current_rev.parent_ids = tree.get_parent_ids()
-        current_rev.committer = branch.get_config().username()
-        current_rev.message = "?"
-        current_rev.timestamp = round(time.time(), 3)
-        current_rev.timezone = osutils.local_time_offset()
-    else:
-        current_rev = None
-    annotation = list(_expand_annotations(annotations, branch,
+    # Create a virtual revision to represent the current tree state.
+    # Should get some more pending commit attributes, like pending tags,
+    # bugfixes etc.
+    current_rev = Revision(CURRENT_REVISION)
+    current_rev.parent_ids = tree.get_parent_ids()
+    current_rev.committer = tree.branch.get_config().username()
+    current_rev.message = "?"
+    current_rev.timestamp = round(time.time(), 3)
+    current_rev.timezone = osutils.local_time_offset()
+    annotation = list(_expand_annotations(annotations, tree.branch,
         current_rev))
     _print_annotations(annotation, verbose, to_file, full)
 
@@ -176,6 +170,13 @@
     return
 
 
+def _annotations(repo, file_id, rev_id):
+    """Return the list of (origin_revision_id, line_text) for a revision of a file in a repository."""
+    annotations = repo.texts.annotate((file_id, rev_id))
+    #
+    return [(key[-1], line) for (key, line) in annotations]
+
+
 def _expand_annotations(annotations, branch, current_rev=None):
     """Expand a file's annotations into command line UI ready tuples.
 
@@ -188,8 +189,8 @@
     """
     repository = branch.repository
     if current_rev is not None:
-        # This can probably become a function on MutableTree, get_revno_map
-        # there, or something.
+        # This can probably become a function on MutableTree, get_revno_map there,
+        # or something.
         last_revision = current_rev.revision_id
         # XXX: Partially Cloned from branch, uses the old_get_graph, eep.
         # XXX: The main difficulty is that we need to inject a single new node

=== modified file 'bzrlib/branch.py'
--- bzrlib/branch.py	2011-04-27 11:25:28 +0000
+++ bzrlib/branch.py	2011-04-27 10:55:49 +0000
@@ -994,6 +994,21 @@
         else:
             return (0, _mod_revision.NULL_REVISION)
 
+    def update_revisions(self, other, stop_revision=None, overwrite=False,
+            graph=None):
+        """Pull in new perfect-fit revisions.
+
+        :param other: Another Branch to pull from
+        :param stop_revision: Updated until the given revision
+        :param overwrite: Always set the branch pointer, rather than checking
+            to see if it is a proper descendant.
+        :param graph: A Graph object that can be used to query history
+            information. This can be None.
+        :return: None
+        """
+        return InterBranch.get(other, self).update_revisions(stop_revision,
+            overwrite, graph)
+
     @deprecated_method(deprecated_in((2, 4, 0)))
     def import_last_revision_info(self, source_repo, revno, revid):
         """Set the last revision info, importing from another repo if necessary.
@@ -2596,6 +2611,27 @@
                 pass
         return None
 
+    def _basic_push(self, target, overwrite, stop_revision):
+        """Basic implementation of push without bound branches or hooks.
+
+        Must be called with source read locked and target write locked.
+        """
+        result = BranchPushResult()
+        result.source_branch = self
+        result.target_branch = target
+        result.old_revno, result.old_revid = target.last_revision_info()
+        self.update_references(target)
+        if result.old_revid != stop_revision:
+            # We assume that during 'push' this repository is closer than
+            # the target.
+            graph = self.repository.get_graph(target.repository)
+            target.update_revisions(self, stop_revision,
+                overwrite=overwrite, graph=graph)
+        if self._push_should_merge_tags():
+            result.tag_conflicts = self.tags.merge_to(target.tags, overwrite)
+        result.new_revno, result.new_revid = target.last_revision_info()
+        return result
+
     def get_stacked_on_url(self):
         raise errors.UnstackableBranchFormat(self._format, self.user_url)
 
@@ -3251,6 +3287,20 @@
         raise NotImplementedError(self.pull)
 
     @needs_write_lock
+    def update_revisions(self, stop_revision=None, overwrite=False,
+            graph=None):
+        """Pull in new perfect-fit revisions.
+
+        :param stop_revision: Updated until the given revision
+        :param overwrite: Always set the branch pointer, rather than checking
+            to see if it is a proper descendant.
+        :param graph: A Graph object that can be used to query history
+            information. This can be None.
+        :return: None
+        """
+        raise NotImplementedError(self.update_revisions)
+
+    @needs_write_lock
     def push(self, overwrite=False, stop_revision=None,
              _override_hook_source_branch=None):
         """Mirror the source branch into the target branch.
@@ -3334,8 +3384,9 @@
             self.source.unlock()
 
     @needs_write_lock
-    def _update_revisions(self, stop_revision=None, overwrite=False,
+    def update_revisions(self, stop_revision=None, overwrite=False,
             graph=None):
+        """See InterBranch.update_revisions()."""
         other_revno, other_last_revision = self.source.last_revision_info()
         stop_revno = None # unknown
         if stop_revision is None:
@@ -3427,28 +3478,6 @@
         finally:
             self.source.unlock()
 
-    def _basic_push(self, overwrite, stop_revision):
-        """Basic implementation of push without bound branches or hooks.
-
-        Must be called with source read locked and target write locked.
-        """
-        result = BranchPushResult()
-        result.source_branch = self.source
-        result.target_branch = self.target
-        result.old_revno, result.old_revid = self.target.last_revision_info()
-        self.source.update_references(self.target)
-        if result.old_revid != stop_revision:
-            # We assume that during 'push' this repository is closer than
-            # the target.
-            graph = self.source.repository.get_graph(self.target.repository)
-            self._update_revisions(stop_revision, overwrite=overwrite,
-                    graph=graph)
-        if self.source._push_should_merge_tags():
-            result.tag_conflicts = self.source.tags.merge_to(self.target.tags,
-                overwrite)
-        result.new_revno, result.new_revid = self.target.last_revision_info()
-        return result
-
     def _push_with_bound_branches(self, overwrite, stop_revision,
             _override_hook_source_branch=None):
         """Push from source into target, and into target's master if any.
@@ -3469,12 +3498,12 @@
             master_branch.lock_write()
             try:
                 # push into the master from the source branch.
-                master_inter = InterBranch.get(self.source, master_branch)
-                master_inter._basic_push(overwrite, stop_revision)
-                # and push into the target branch from the source. Note that
-                # we push from the source branch again, because it's considered
-                # the highest bandwidth repository.
-                result = self._basic_push(overwrite, stop_revision)
+                self.source._basic_push(master_branch, overwrite, stop_revision)
+                # and push into the target branch from the source. Note that we
+                # push from the source branch again, because it's considered the
+                # highest bandwidth repository.
+                result = self.source._basic_push(self.target, overwrite,
+                    stop_revision)
                 result.master_branch = master_branch
                 result.local_branch = self.target
                 _run_hooks()
@@ -3483,7 +3512,8 @@
                 master_branch.unlock()
         else:
             # no master branch
-            result = self._basic_push(overwrite, stop_revision)
+            result = self.source._basic_push(self.target, overwrite,
+                stop_revision)
             # TODO: Why set master_branch and local_branch if there's no
             # binding?  Maybe cleaner to just leave them unset? -- mbp
             # 20070504
@@ -3532,8 +3562,8 @@
             # -- JRV20090506
             result.old_revno, result.old_revid = \
                 self.target.last_revision_info()
-            self._update_revisions(stop_revision, overwrite=overwrite,
-                graph=graph)
+            self.target.update_revisions(self.source, stop_revision,
+                overwrite=overwrite, graph=graph)
             # TODO: The old revid should be specified when merging tags, 
             # so a tags implementation that versions tags can only 
             # pull in the most recent changes. -- JRV20090506

=== modified file 'bzrlib/builtins.py'
--- bzrlib/builtins.py	2011-05-08 17:58:08 +0000
+++ bzrlib/builtins.py	2011-04-28 12:26:34 +0000
@@ -4693,9 +4693,7 @@
     @display_command
     def run(self, filename, all=False, long=False, revision=None,
             show_ids=False, directory=None):
-        from bzrlib.annotate import (
-            annotate_file_tree,
-            )
+        from bzrlib.annotate import annotate_file, annotate_file_tree
         wt, branch, relpath = \
             _open_directory_or_containing_tree_or_branch(filename, directory)
         if wt is not None:
@@ -4716,8 +4714,9 @@
             annotate_file_tree(wt, file_id, self.outf, long, all,
                 show_ids=show_ids)
         else:
-            annotate_file_tree(tree, file_id, self.outf, long, all,
-                show_ids=show_ids, branch=branch)
+            file_version = tree.get_file_revision(file_id)
+            annotate_file(branch, file_version, file_id, long, all, self.outf,
+                          show_ids=show_ids)
 
 
 class cmd_re_sign(Command):
@@ -6154,16 +6153,6 @@
             self.outf.write('%s %s\n' % (path, location))
 
 
-class cmd_export_pot(Command):
-    __doc__ = """Export command helps and error messages in po format."""
-
-    hidden = True
-
-    def run(self):
-        from bzrlib.export_pot import export_pot
-        export_pot(self.outf)
-
-
 def _register_lazy_builtins():
     # register lazy builtins from other modules; called at startup and should
     # be only called once.

=== modified file 'bzrlib/bzrdir.py'
--- bzrlib/bzrdir.py	2011-05-04 14:54:13 +0000
+++ bzrlib/bzrdir.py	2011-05-03 23:16:56 +0000
@@ -49,7 +49,7 @@
     ui,
     urlutils,
     win32utils,
-    workingtree_3,
+    workingtree,
     workingtree_4,
     )
 from bzrlib.repofmt import knitpack_repo
@@ -1883,7 +1883,7 @@
         else:
             # TODO: conversions of Branch and Tree should be done by
             # InterXFormat lookups
-            if (isinstance(tree, workingtree_3.WorkingTree3) and
+            if (isinstance(tree, workingtree.WorkingTree3) and
                 not isinstance(tree, workingtree_4.DirStateWorkingTree) and
                 isinstance(self.target_format.workingtree_format,
                     workingtree_4.DirStateWorkingTreeFormat)):
@@ -2110,7 +2110,7 @@
     'bzrlib.repofmt.knitrepo.RepositoryFormatKnit1',
     'Format using knits.  Recommended for interoperation with bzr <= 0.14.',
     branch_format='bzrlib.branch.BzrBranchFormat5',
-    tree_format='bzrlib.workingtree_3.WorkingTreeFormat3',
+    tree_format='bzrlib.workingtree.WorkingTreeFormat3',
     hidden=True,
     deprecated=True)
 register_metadir(controldir.format_registry, 'dirstate',

=== removed file 'bzrlib/export_pot.py'
--- bzrlib/export_pot.py	2011-05-12 12:19:35 +0000
+++ bzrlib/export_pot.py	1970-01-01 00:00:00 +0000
@@ -1,241 +0,0 @@
-# Copyright (C) 2011 Canonical Ltd
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
-
-# The normalize function is taken from pygettext which is distributed
-# with Python under the Python License, which is GPL compatible.
-
-"""Extract docstrings from Bazaar commands.
-"""
-
-import inspect
-import os
-
-from bzrlib import (
-    commands as _mod_commands,
-    errors,
-    help_topics,
-    plugin,
-    )
-from bzrlib.trace import (
-    mutter,
-    note,
-    )
-
-
-def _escape(s):
-    s = (s.replace('\\', '\\\\')
-        .replace('\n', '\\n')
-        .replace('\r', '\\r')
-        .replace('\t', '\\t')
-        .replace('"', '\\"')
-        )
-    return s
-
-def _normalize(s):
-    # This converts the various Python string types into a format that
-    # is appropriate for .po files, namely much closer to C style.
-    lines = s.split('\n')
-    if len(lines) == 1:
-        s = '"' + _escape(s) + '"'
-    else:
-        if not lines[-1]:
-            del lines[-1]
-            lines[-1] = lines[-1] + '\n'
-        lines = map(_escape, lines)
-        lineterm = '\\n"\n"'
-        s = '""\n"' + lineterm.join(lines) + '"'
-    return s
-
-
-_FOUND_MSGID = None # set by entry function.
-
-def _poentry(outf, path, lineno, s, comment=None):
-    if s in _FOUND_MSGID:
-        return
-    _FOUND_MSGID.add(s)
-    if comment is None:
-        comment = ''
-    else:
-        comment = "# %s\n" % comment
-    mutter("Exporting msg %r at line %d in %r", s[:20], lineno, path)
-    print >>outf, ('#: %s:%d\n' % (path, lineno) +
-           comment+
-           'msgid %s\n' % _normalize(s) +
-           'msgstr ""\n')
-
-def _poentry_per_paragraph(outf, path, lineno, msgid):
-    # TODO: How to split long help?
-    paragraphs = msgid.split('\n\n')
-    for p in paragraphs:
-        _poentry(outf, path, lineno, p)
-        lineno += p.count('\n') + 2
-
-_LAST_CACHE = _LAST_CACHED_SRC = None
-
-def _offsets_of_literal(src):
-    global _LAST_CACHE, _LAST_CACHED_SRC
-    if src == _LAST_CACHED_SRC:
-        return _LAST_CACHE.copy()
-
-    import ast
-    root = ast.parse(src)
-    offsets = {}
-    for node in ast.walk(root):
-        if not isinstance(node, ast.Str):
-            continue
-        offsets[node.s] = node.lineno - node.s.count('\n')
-
-    _LAST_CACHED_SRC = src
-    _LAST_CACHE = offsets.copy()
-    return offsets
-
-def _standard_options(outf):
-    from bzrlib.option import Option
-    src = inspect.findsource(Option)[0]
-    src = ''.join(src)
-    path = 'bzrlib/option.py'
-    offsets = _offsets_of_literal(src)
-
-    for name in sorted(Option.OPTIONS.keys()):
-        opt = Option.OPTIONS[name]
-        if getattr(opt, 'hidden', False):
-            continue
-        if getattr(opt, 'title', None):
-            lineno = offsets.get(opt.title, 9999)
-            if lineno == 9999:
-                note("%r is not found in bzrlib/option.py" % opt.title)
-            _poentry(outf, path, lineno, opt.title,
-                     'title of %r option' % name)
-        if getattr(opt, 'help', None):
-            lineno = offsets.get(opt.help, 9999)
-            if lineno == 9999:
-                note("%r is not found in bzrlib/option.py" % opt.help)
-            _poentry(outf, path, lineno, opt.help,
-                     'help of %r option' % name)
-
-def _command_options(outf, path, cmd):
-    src, default_lineno = inspect.findsource(cmd.__class__)
-    offsets = _offsets_of_literal(''.join(src))
-    for opt in cmd.takes_options:
-        if isinstance(opt, str):
-            continue
-        if getattr(opt, 'hidden', False):
-            continue
-        name = opt.name
-        if getattr(opt, 'title', None):
-            lineno = offsets.get(opt.title, default_lineno)
-            _poentry(outf, path, lineno, opt.title,
-                     'title of %r option of %r command' % (name, cmd.name()))
-        if getattr(opt, 'help', None):
-            lineno = offsets.get(opt.help, default_lineno)
-            _poentry(outf, path, lineno, opt.help,
-                     'help of %r option of %r command' % (name, cmd.name()))
-
-
-def _write_command_help(outf, cmd_name, cmd):
-    path = inspect.getfile(cmd.__class__)
-    if path.endswith('.pyc'):
-        path = path[:-1]
-    path = os.path.relpath(path)
-    src, lineno = inspect.findsource(cmd.__class__)
-    offsets = _offsets_of_literal(''.join(src))
-    lineno = offsets[cmd.__doc__]
-    doc = inspect.getdoc(cmd)
-
-    _poentry_per_paragraph(outf, path, lineno, doc)
-    _command_options(outf, path, cmd)
-
-def _command_helps(outf):
-    """Extract docstrings from path.
-
-    This respects the Bazaar cmdtable/table convention and will
-    only extract docstrings from functions mentioned in these tables.
-    """
-    from glob import glob
-
-    # builtin commands
-    for cmd_name in _mod_commands.builtin_command_names():
-        command = _mod_commands.get_cmd_object(cmd_name, False)
-        if command.hidden:
-            continue
-        note("Exporting messages from builtin command: %s", cmd_name)
-        _write_command_help(outf, cmd_name, command)
-
-    plugin_path = plugin.get_core_plugin_path()
-    core_plugins = glob(plugin_path + '/*/__init__.py')
-    core_plugins = [os.path.basename(os.path.dirname(p))
-                        for p in core_plugins]
-    # core plugins
-    for cmd_name in _mod_commands.plugin_command_names():
-        command = _mod_commands.get_cmd_object(cmd_name, False)
-        if command.hidden:
-            continue
-        if command.plugin_name() not in core_plugins:
-            # skip non-core plugins
-            # TODO: Support extracting from third party plugins.
-            continue
-        note("Exporting messages from plugin command: %s in %s",
-             cmd_name, command.plugin_name())
-        _write_command_help(outf, cmd_name, command)
-
-
-def _error_messages(outf):
-    """Extract fmt string from bzrlib.errors."""
-    path = errors.__file__
-    if path.endswith('.pyc'):
-        path = path[:-1]
-    offsets = _offsets_of_literal(open(path).read())
-
-    base_klass = errors.BzrError
-    for name in dir(errors):
-        klass = getattr(errors, name)
-        if not inspect.isclass(klass):
-            continue
-        if not issubclass(klass, base_klass):
-            continue
-        if klass is base_klass:
-            continue
-        if klass.internal_error:
-            continue
-        fmt = getattr(klass, "_fmt", None)
-        if fmt:
-            note("Exporting message from error: %s", name)
-            _poentry(outf, 'bzrlib/errors.py',
-                     offsets.get(fmt, 9999), fmt)
-
-def _help_topics(outf):
-    topic_registry = help_topics.topic_registry
-    for key in topic_registry.keys():
-        doc = topic_registry.get(key)
-        if isinstance(doc, str):
-            _poentry_per_paragraph(
-                    outf,
-                    'dummy/help_topics/'+key+'/detail.txt',
-                    1, doc)
-
-        summary = topic_registry.get_summary(key)
-        if summary is not None:
-            _poentry(outf, 'dummy/help_topics/'+key+'/summary.txt',
-                     1, summary)
-
-def export_pot(outf):
-    global _FOUND_MSGID
-    _FOUND_MSGID = set()
-    _standard_options(outf)
-    _command_helps(outf)
-    _error_messages(outf)
-    # disable exporting help topics until we decide  how to translate it.
-    #_help_topics(outf)

=== modified file 'bzrlib/plugins/weave_fmt/__init__.py'
--- bzrlib/plugins/weave_fmt/__init__.py	2011-05-04 22:23:20 +0000
+++ bzrlib/plugins/weave_fmt/__init__.py	2011-03-13 00:08:28 +0000
@@ -82,7 +82,7 @@
     'bzrlib.plugins.weave_fmt.repository.RepositoryFormat7',
     'Transitional format in 0.8.  Slower than knit.',
     branch_format='bzrlib.branch.BzrBranchFormat5',
-    tree_format='bzrlib.workingtree_3.WorkingTreeFormat3',
+    tree_format='bzrlib.workingtree.WorkingTreeFormat3',
     hidden=True,
     deprecated=True)
 

=== modified file 'bzrlib/plugins/weave_fmt/bzrdir.py'
--- bzrlib/plugins/weave_fmt/bzrdir.py	2011-05-04 22:23:20 +0000
+++ bzrlib/plugins/weave_fmt/bzrdir.py	2011-03-23 13:26:59 +0000
@@ -599,7 +599,7 @@
                 if name in bzrcontents:
                     self.bzrdir.transport.delete(name)
         else:
-            from bzrlib.workingtree_3 import WorkingTreeFormat3
+            from bzrlib.workingtree import WorkingTreeFormat3
             self.step('Upgrading working tree')
             self.bzrdir.transport.mkdir('checkout', mode=self.dir_mode)
             self.make_lock('checkout')

=== modified file 'bzrlib/plugins/weave_fmt/workingtree.py'
--- bzrlib/plugins/weave_fmt/workingtree.py	2011-05-04 22:38:14 +0000
+++ bzrlib/plugins/weave_fmt/workingtree.py	2011-04-09 22:51:57 +0000
@@ -227,8 +227,4 @@
                              file_id=self.path2id(conflicted)))
         return conflicts
 
-    def set_conflicts(self, arg):
-        raise errors.UnsupportedOperation(self.set_conflicts, self)
 
-    def add_conflicts(self, arg):
-        raise errors.UnsupportedOperation(self.add_conflicts, self)

=== modified file 'bzrlib/tests/__init__.py'
--- bzrlib/tests/__init__.py	2011-05-09 10:21:57 +0000
+++ bzrlib/tests/__init__.py	2011-04-21 01:19:32 +0000
@@ -3784,7 +3784,6 @@
         'bzrlib.tests.test_eol_filters',
         'bzrlib.tests.test_errors',
         'bzrlib.tests.test_export',
-        'bzrlib.tests.test_export_pot',
         'bzrlib.tests.test_extract',
         'bzrlib.tests.test_fetch',
         'bzrlib.tests.test_fixtures',

=== modified file 'bzrlib/tests/blackbox/test_exceptions.py'
--- bzrlib/tests/blackbox/test_exceptions.py	2011-05-04 19:55:26 +0000
+++ bzrlib/tests/blackbox/test_exceptions.py	2011-05-03 22:59:49 +0000
@@ -55,7 +55,7 @@
         if os.name != "posix":
             raise tests.TestNotApplicable("Needs system beholden to C locales")
         out, err = self.run_bzr_subprocess(["\xa0"],
-            env_changes={"LANG": "C", "LC_ALL": "C"},
+            env_changes={"LANG": "C"},
             universal_newlines=True,
             retcode=errors.EXIT_ERROR)
         self.assertContainsRe(err, r"^bzr: ERROR: .*'\\xa0'.* unsupported")

=== modified file 'bzrlib/tests/per_branch/test_update.py'
--- bzrlib/tests/per_branch/test_update.py	2011-04-27 13:26:31 +0000
+++ bzrlib/tests/per_branch/test_update.py	2011-01-10 21:31:59 +0000
@@ -70,6 +70,54 @@
         self.assertEqual('foo', child_tree.branch.update())
         self.assertEqual(['bar'], child_tree.branch.revision_history())
 
+
+class TestUpdateRevisions(per_branch.TestCaseWithBranch):
+
+    def test_accepts_graph(self):
+        # An implementation may not use it, but it should allow a 'graph' to be
+        # supplied
+        tree1 = self.make_branch_and_tree('tree1')
+        rev1 = tree1.commit('one')
+        tree2 = tree1.bzrdir.sprout('tree2').open_workingtree()
+        rev2 = tree2.commit('two')
+
+        tree1.lock_write()
+        self.addCleanup(tree1.unlock)
+        tree2.lock_read()
+        self.addCleanup(tree2.unlock)
+        graph = tree2.branch.repository.get_graph(tree1.branch.repository)
+
+        tree1.branch.update_revisions(tree2.branch, graph=graph)
+        self.assertEqual((2, rev2), tree1.branch.last_revision_info())
+
+    def test_overwrite_ignores_diverged(self):
+        tree1 = self.make_branch_and_tree('tree1')
+        rev1 = tree1.commit('one')
+        tree2 = tree1.bzrdir.sprout('tree2').open_workingtree()
+        rev2 = tree1.commit('two')
+        rev2b = tree2.commit('alt two')
+
+        self.assertRaises(errors.DivergedBranches,
+                          tree1.branch.update_revisions,
+                          tree2.branch, overwrite=False)
+        # However, the revision should be copied into the repository
+        self.assertTrue(tree1.branch.repository.has_revision(rev2b))
+
+        tree1.branch.update_revisions(tree2.branch, overwrite=True)
+        self.assertEqual((2, rev2b), tree1.branch.last_revision_info())
+
+    def test_ignores_older_unless_overwrite(self):
+        tree1 = self.make_branch_and_tree('tree1')
+        rev1 = tree1.commit('one')
+        tree2 = tree1.bzrdir.sprout('tree2').open_workingtree()
+        rev2 = tree1.commit('two')
+
+        tree1.branch.update_revisions(tree2.branch)
+        self.assertEqual((2, rev2), tree1.branch.last_revision_info())
+
+        tree1.branch.update_revisions(tree2.branch, overwrite=True)
+        self.assertEqual((1, rev1), tree1.branch.last_revision_info())
+
     def test_update_in_checkout_of_readonly(self):
         tree1 = self.make_branch_and_tree('tree1')
         rev1 = tree1.commit('one')

=== modified file 'bzrlib/tests/per_interbranch/__init__.py'
--- bzrlib/tests/per_interbranch/__init__.py	2011-04-27 13:26:31 +0000
+++ bzrlib/tests/per_interbranch/__init__.py	2011-03-26 01:53:34 +0000
@@ -171,6 +171,7 @@
         'bzrlib.tests.per_interbranch.test_copy_content_into',
         'bzrlib.tests.per_interbranch.test_pull',
         'bzrlib.tests.per_interbranch.test_push',
+        'bzrlib.tests.per_interbranch.test_update_revisions',
         ])
     scenarios = make_scenarios(default_test_list())
     return multiply_tests(submod_tests, scenarios, standard_tests)

=== added file 'bzrlib/tests/per_interbranch/test_update_revisions.py'
--- bzrlib/tests/per_interbranch/test_update_revisions.py	1970-01-01 00:00:00 +0000
+++ bzrlib/tests/per_interbranch/test_update_revisions.py	2010-06-17 09:23:19 +0000
@@ -0,0 +1,70 @@
+# Copyright (C) 2009, 2010 Canonical Ltd
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+
+from bzrlib import (
+    errors,
+    )
+from bzrlib.tests.per_interbranch import (
+    TestCaseWithInterBranch,
+    )
+
+
+class TestUpdateRevisions(TestCaseWithInterBranch):
+
+    def setUp(self):
+        super(TestUpdateRevisions, self).setUp()
+        self.tree1 = self.make_from_branch_and_tree('tree1')
+        rev1 = self.tree1.commit('one')
+        branch2 = self.make_to_branch('tree2')
+        branch2.repository.fetch(self.tree1.branch.repository)
+        self.tree1.branch.copy_content_into(branch2)
+        self.tree2 = branch2.bzrdir.create_workingtree()
+
+    def test_accepts_graph(self):
+        # An implementation may not use it, but it should allow a 'graph' to be
+        # supplied
+        rev2 = self.tree2.commit('two')
+
+        self.tree1.lock_write()
+        self.addCleanup(self.tree1.unlock)
+        self.tree2.lock_read()
+        self.addCleanup(self.tree2.unlock)
+        graph = self.tree2.branch.repository.get_graph(
+            self.tree1.branch.repository)
+
+        self.tree1.branch.update_revisions(self.tree2.branch, graph=graph)
+        self.assertEqual((2, rev2), self.tree1.branch.last_revision_info())
+
+    def test_overwrite_ignores_diverged(self):
+        rev2 = self.tree1.commit('two')
+        rev2b = self.tree2.commit('alt two')
+
+        self.assertRaises(errors.DivergedBranches,
+                          self.tree1.branch.update_revisions,
+                          self.tree2.branch, overwrite=False)
+        # However, the revision should be copied into the repository
+        self.assertTrue(self.tree1.branch.repository.has_revision(rev2b))
+
+        self.tree1.branch.update_revisions(self.tree2.branch, overwrite=True)
+        self.assertEqual((2, rev2b), self.tree1.branch.last_revision_info())
+
+    def test_ignores_older_unless_overwrite(self):
+        rev2 = self.tree1.commit('two')
+
+        self.tree1.branch.update_revisions(self.tree2.branch)
+        self.assertEqual((2, rev2), self.tree1.branch.last_revision_info())
+
+        self.tree1.branch.update_revisions(self.tree2.branch, overwrite=True)

=== modified file 'bzrlib/tests/per_intertree/__init__.py'
--- bzrlib/tests/per_intertree/__init__.py	2011-05-03 23:54:46 +0000
+++ bzrlib/tests/per_intertree/__init__.py	2010-11-22 03:35:24 +0000
@@ -24,6 +24,7 @@
 
 import bzrlib
 from bzrlib import (
+    errors,
     revisiontree,
     tests,
     )
@@ -38,7 +39,9 @@
     TestCaseWithTree,
     )
 from bzrlib.tree import InterTree
-from bzrlib.workingtree_3 import WorkingTreeFormat3
+from bzrlib.workingtree import (
+    WorkingTreeFormat3,
+    )
 from bzrlib.workingtree_4 import WorkingTreeFormat4
 
 

=== modified file 'bzrlib/tests/per_repository/__init__.py'
--- bzrlib/tests/per_repository/__init__.py	2011-05-02 22:39:15 +0000
+++ bzrlib/tests/per_repository/__init__.py	2011-03-09 01:33:12 +0000
@@ -110,6 +110,7 @@
     prefix = 'bzrlib.tests.per_repository.'
     test_repository_modules = [
         'test_add_fallback_repository',
+        'test_add_inventory_by_delta',
         'test_break_lock',
         'test_check',
         'test_commit_builder',

=== modified file 'bzrlib/tests/per_repository/test_add_fallback_repository.py'
--- bzrlib/tests/per_repository/test_add_fallback_repository.py	2011-05-02 22:39:15 +0000
+++ bzrlib/tests/per_repository/test_add_fallback_repository.py	2009-08-13 05:17:12 +0000
@@ -17,7 +17,9 @@
 """Tests for Repository.add_fallback_repository."""
 
 from bzrlib import (
+    bzrdir,
     errors,
+    remote,
     )
 from bzrlib.revision import NULL_REVISION
 from bzrlib.tests import TestNotApplicable

=== renamed file 'bzrlib/tests/per_repository_vf/test_add_inventory_by_delta.py' => 'bzrlib/tests/per_repository/test_add_inventory_by_delta.py'
--- bzrlib/tests/per_repository_vf/test_add_inventory_by_delta.py	2011-05-02 22:39:15 +0000
+++ bzrlib/tests/per_repository/test_add_inventory_by_delta.py	2009-06-18 18:18:36 +0000
@@ -17,19 +17,11 @@
 """Tests for Repository.add_inventory_by_delta."""
 
 from bzrlib import errors, revision
-from bzrlib.tests.per_repository_vf import (
-    all_repository_vf_format_scenarios,
-    TestCaseWithRepository
-    )
-from bzrlib.tests.scenarios import load_tests_apply_scenarios
-
-load_tests = load_tests_apply_scenarios
+from bzrlib.tests.per_repository import TestCaseWithRepository
 
 
 class TestAddInventoryByDelta(TestCaseWithRepository):
 
-    scenarios = all_repository_vf_format_scenarios()
-
     def _get_repo_in_write_group(self, path='repository'):
         repo = self.make_repository(path)
         repo.lock_write()

=== modified file 'bzrlib/tests/per_repository/test_commit_builder.py'
--- bzrlib/tests/per_repository/test_commit_builder.py	2011-05-04 13:00:00 +0000
+++ bzrlib/tests/per_repository/test_commit_builder.py	2011-04-17 23:06:22 +0000
@@ -535,8 +535,7 @@
         basis_tree = tree.basis_tree()
         basis_tree.lock_read()
         self.addCleanup(basis_tree.unlock)
-        self.assertEqual(rev_id,
-            basis_tree.get_file_revision(basis_tree.get_root_id()))
+        self.assertEqual(rev_id, basis_tree.inventory.root.revision)
 
     def _get_revtrees(self, tree, revision_ids):
         tree.lock_read()
@@ -556,13 +555,11 @@
         rev1 = tree.commit('')
         rev2 = tree.commit('')
         tree1, tree2 = self._get_revtrees(tree, [rev1, rev2])
-        self.assertEqual(rev1, tree1.get_file_revision(tree1.get_root_id()))
+        self.assertEqual(rev1, tree1.inventory.root.revision)
         if tree.branch.repository.supports_rich_root():
-            self.assertEqual(rev1,
-                tree2.get_file_revision(tree2.get_root_id()))
+            self.assertEqual(rev1, tree2.inventory.root.revision)
         else:
-            self.assertEqual(rev2,
-                tree2.get_file_revision(tree2.get_root_id()))
+            self.assertEqual(rev2, tree2.inventory.root.revision)
 
     def _add_commit_check_unchanged(self, tree, name, mini_commit=None):
         tree.add([name], [name + 'id'])

=== modified file 'bzrlib/tests/per_repository/test_fetch.py'
--- bzrlib/tests/per_repository/test_fetch.py	2011-05-02 22:44:40 +0000
+++ bzrlib/tests/per_repository/test_fetch.py	2011-04-02 20:53:50 +0000
@@ -20,6 +20,7 @@
     bzrdir,
     errors,
     gpg,
+    graph,
     remote,
     repository,
     tests,
@@ -355,3 +356,29 @@
         self.addCleanup(source.unlock)
         target.fetch(source, revision_id='B-id')
 
+
+class TestSource(TestCaseWithRepository):
+    """Tests for/about the results of Repository._get_source."""
+
+    def test_no_absent_records_in_stream_with_ghosts(self):
+        # XXX: Arguably should be in per_interrepository but
+        # doesn't actually gain coverage there; need a specific set of
+        # permutations to cover it.
+        # bug lp:376255 was reported about this.
+        builder = self.make_branch_builder('repo')
+        builder.start_series()
+        builder.build_snapshot('tip', ['ghost'],
+            [('add', ('', 'ROOT_ID', 'directory', ''))],
+            allow_leftmost_as_ghost=True)
+        builder.finish_series()
+        b = builder.get_branch()
+        b.lock_read()
+        self.addCleanup(b.unlock)
+        repo = b.repository
+        source = repo._get_source(repo._format)
+        search = graph.PendingAncestryResult(['tip'], repo)
+        stream = source.get_stream(search)
+        for substream_type, substream in stream:
+            for record in substream:
+                self.assertNotEqual('absent', record.storage_kind,
+                    "Absent record for %s" % (((substream_type,) + record.key),))

=== modified file 'bzrlib/tests/per_repository/test_repository.py'
--- bzrlib/tests/per_repository/test_repository.py	2011-05-04 21:10:36 +0000
+++ bzrlib/tests/per_repository/test_repository.py	2011-04-16 10:11:51 +0000
@@ -210,8 +210,8 @@
         rev_tree = tree.branch.repository.revision_tree(second_revision)
         rev_tree.lock_read()
         self.addCleanup(rev_tree.unlock)
-        root_revision = rev_tree.get_file_revision(rev_tree.get_root_id())
-        rich_root = (root_revision != second_revision)
+        inv = rev_tree.inventory
+        rich_root = (inv.root.revision != second_revision)
         self.assertEqual(rich_root,
                          tree.branch.repository.supports_rich_root())
 
@@ -320,8 +320,7 @@
         tree = wt.branch.repository.revision_tree('revision-1')
         tree.lock_read()
         try:
-            self.assertEqual('revision-1',
-                tree.get_file_revision(tree.get_root_id()))
+            self.assertEqual('revision-1', tree.inventory.root.revision)
             expected = inventory.InventoryDirectory('fixed-root', '', None)
             expected.revision = 'revision-1'
             self.assertEqual([('', 'V', 'directory', 'fixed-root', expected)],
@@ -546,8 +545,7 @@
         rev_tree = tree.branch.repository.revision_tree(tree.last_revision())
         rev_tree.lock_read()
         self.addCleanup(rev_tree.unlock)
-        root_id = rev_tree.get_root_id()
-        self.assertEqual('rev_id', rev_tree.get_file_revision(root_id))
+        self.assertEqual('rev_id', rev_tree.inventory.root.revision)
 
     def test_pointless_commit(self):
         tree = self.make_branch_and_tree('.')
@@ -563,6 +561,11 @@
         repo._format.rich_root_data
         repo._format.supports_tree_reference
 
+    def test_get_serializer_format(self):
+        repo = self.make_repository('.')
+        format = repo.get_serializer_format()
+        self.assertEqual(repo._serializer.format_num, format)
+
     def test_iter_files_bytes(self):
         tree = self.make_branch_and_tree('tree')
         self.build_tree_contents([('tree/file1', 'foo'),
@@ -632,8 +635,8 @@
             # expected_record_names.
             # Note that the file keys can be in any order, so this test is
             # written to allow that.
-            rev_tree = repo.revision_tree('rev_id')
-            root_item_key = ('file', rev_tree.get_root_id(), ['rev_id'])
+            inv = repo.get_inventory('rev_id')
+            root_item_key = ('file', inv.root.file_id, ['rev_id'])
             self.assertTrue(root_item_key in item_keys)
             item_keys.remove(root_item_key)
 
@@ -727,6 +730,55 @@
                 b.repository.add_signature_text, 'A',
                 'This might be a signature')
 
+    def test_add_revision_inventory_sha1(self):
+        inv = inventory.Inventory(revision_id='A')
+        inv.root.revision = 'A'
+        inv.root.file_id = 'fixed-root'
+        # Insert the inventory on its own to an identical repository, to get
+        # its sha1.
+        reference_repo = self.make_repository('reference_repo')
+        reference_repo.lock_write()
+        reference_repo.start_write_group()
+        inv_sha1 = reference_repo.add_inventory('A', inv, [])
+        reference_repo.abort_write_group()
+        reference_repo.unlock()
+        # Now insert a revision with this inventory, and it should get the same
+        # sha1.
+        repo = self.make_repository('repo')
+        repo.lock_write()
+        repo.start_write_group()
+        root_id = inv.root.file_id
+        repo.texts.add_lines(('fixed-root', 'A'), [], [])
+        repo.add_revision('A', _mod_revision.Revision(
+                'A', committer='B', timestamp=0,
+                timezone=0, message='C'), inv=inv)
+        repo.commit_write_group()
+        repo.unlock()
+        repo.lock_read()
+        self.assertEquals(inv_sha1, repo.get_revision('A').inventory_sha1)
+        repo.unlock()
+
+    def test_install_revisions(self):
+        wt = self.make_branch_and_tree('source')
+        wt.commit('A', allow_pointless=True, rev_id='A')
+        repo = wt.branch.repository
+        repo.lock_write()
+        repo.start_write_group()
+        repo.sign_revision('A', gpg.LoopbackGPGStrategy(None))
+        repo.commit_write_group()
+        repo.unlock()
+        repo.lock_read()
+        self.addCleanup(repo.unlock)
+        repo2 = self.make_repository('repo2')
+        revision = repo.get_revision('A')
+        tree = repo.revision_tree('A')
+        signature = repo.get_signature_text('A')
+        repo2.lock_write()
+        self.addCleanup(repo2.unlock)
+        repository.install_revisions(repo2, [(revision, tree, signature)])
+        self.assertEqual(revision, repo2.get_revision('A'))
+        self.assertEqual(signature, repo2.get_signature_text('A'))
+
     # XXX: this helper duplicated from tests.test_repository
     def make_remote_repository(self, path, shared=False):
         """Make a RemoteRepository object backed by a real repository that will

=== modified file 'bzrlib/tests/per_repository_vf/__init__.py'
--- bzrlib/tests/per_repository_vf/__init__.py	2011-05-02 22:44:40 +0000
+++ bzrlib/tests/per_repository_vf/__init__.py	2011-04-19 12:48:51 +0000
@@ -37,10 +37,8 @@
 
 def load_tests(basic_tests, module, loader):
     testmod_names = [
-        'test_add_inventory_by_delta',
         'test_check',
         'test_check_reconcile',
-        'test_fetch',
         'test_reconcile',
         'test_repository',
         ]

=== removed file 'bzrlib/tests/per_repository_vf/test_fetch.py'
--- bzrlib/tests/per_repository_vf/test_fetch.py	2011-05-02 22:44:40 +0000
+++ bzrlib/tests/per_repository_vf/test_fetch.py	1970-01-01 00:00:00 +0000
@@ -1,57 +0,0 @@
-# Copyright (C) 2007-2011 Canonical Ltd
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
-
-"""Tests for fetch between repositories of the same type."""
-
-from bzrlib import (
-    graph,
-    )
-from bzrlib.tests.per_repository_vf import (
-    TestCaseWithRepository,
-    all_repository_vf_format_scenarios,
-    )
-from bzrlib.tests.scenarios import load_tests_apply_scenarios
-
-load_tests = load_tests_apply_scenarios
-
-
-class TestSource(TestCaseWithRepository):
-    """Tests for/about the results of Repository._get_source."""
-
-    scenarios = all_repository_vf_format_scenarios()
-
-    def test_no_absent_records_in_stream_with_ghosts(self):
-        # XXX: Arguably should be in per_interrepository but
-        # doesn't actually gain coverage there; need a specific set of
-        # permutations to cover it.
-        # bug lp:376255 was reported about this.
-        builder = self.make_branch_builder('repo')
-        builder.start_series()
-        builder.build_snapshot('tip', ['ghost'],
-            [('add', ('', 'ROOT_ID', 'directory', ''))],
-            allow_leftmost_as_ghost=True)
-        builder.finish_series()
-        b = builder.get_branch()
-        b.lock_read()
-        self.addCleanup(b.unlock)
-        repo = b.repository
-        source = repo._get_source(repo._format)
-        search = graph.PendingAncestryResult(['tip'], repo)
-        stream = source.get_stream(search)
-        for substream_type, substream in stream:
-            for record in substream:
-                self.assertNotEqual('absent', record.storage_kind,
-                    "Absent record for %s" % (((substream_type,) + record.key),))

=== modified file 'bzrlib/tests/per_repository_vf/test_repository.py'
--- bzrlib/tests/per_repository_vf/test_repository.py	2011-05-04 21:10:36 +0000
+++ bzrlib/tests/per_repository_vf/test_repository.py	2011-03-14 00:09:25 +0000
@@ -18,10 +18,6 @@
 
 from bzrlib import (
     errors,
-    gpg,
-    inventory,
-    repository as _mod_repository,
-    revision as _mod_revision,
     tests,
     versionedfile,
     )
@@ -116,60 +112,6 @@
         self.assertRaises(errors.ObjectNotLocked,
             inventories.add_lines, ('foo',), [], [])
 
-    def test_get_serializer_format(self):
-        repo = self.make_repository('.')
-        format = repo.get_serializer_format()
-        self.assertEqual(repo._serializer.format_num, format)
-
-    def test_add_revision_inventory_sha1(self):
-        inv = inventory.Inventory(revision_id='A')
-        inv.root.revision = 'A'
-        inv.root.file_id = 'fixed-root'
-        # Insert the inventory on its own to an identical repository, to get
-        # its sha1.
-        reference_repo = self.make_repository('reference_repo')
-        reference_repo.lock_write()
-        reference_repo.start_write_group()
-        inv_sha1 = reference_repo.add_inventory('A', inv, [])
-        reference_repo.abort_write_group()
-        reference_repo.unlock()
-        # Now insert a revision with this inventory, and it should get the same
-        # sha1.
-        repo = self.make_repository('repo')
-        repo.lock_write()
-        repo.start_write_group()
-        root_id = inv.root.file_id
-        repo.texts.add_lines(('fixed-root', 'A'), [], [])
-        repo.add_revision('A', _mod_revision.Revision(
-                'A', committer='B', timestamp=0,
-                timezone=0, message='C'), inv=inv)
-        repo.commit_write_group()
-        repo.unlock()
-        repo.lock_read()
-        self.assertEquals(inv_sha1, repo.get_revision('A').inventory_sha1)
-        repo.unlock()
-
-    def test_install_revisions(self):
-        wt = self.make_branch_and_tree('source')
-        wt.commit('A', allow_pointless=True, rev_id='A')
-        repo = wt.branch.repository
-        repo.lock_write()
-        repo.start_write_group()
-        repo.sign_revision('A', gpg.LoopbackGPGStrategy(None))
-        repo.commit_write_group()
-        repo.unlock()
-        repo.lock_read()
-        self.addCleanup(repo.unlock)
-        repo2 = self.make_repository('repo2')
-        revision = repo.get_revision('A')
-        tree = repo.revision_tree('A')
-        signature = repo.get_signature_text('A')
-        repo2.lock_write()
-        self.addCleanup(repo2.unlock)
-        _mod_repository.install_revisions(repo2, [(revision, tree, signature)])
-        self.assertEqual(revision, repo2.get_revision('A'))
-        self.assertEqual(signature, repo2.get_signature_text('A'))
-
 
 class TestCaseWithComplexRepository(TestCaseWithRepository):
 

=== modified file 'bzrlib/tests/per_tree/test_inv.py'
--- bzrlib/tests/per_tree/test_inv.py	2011-04-20 14:58:20 +0000
+++ bzrlib/tests/per_tree/test_inv.py	2011-04-09 21:00:33 +0000
@@ -25,7 +25,6 @@
     )
 from bzrlib.mutabletree import MutableTree
 from bzrlib.tests import TestSkipped
-from bzrlib.tree import InventoryTree
 from bzrlib.transform import _PreviewTree
 from bzrlib.uncommit import uncommit
 
@@ -137,49 +136,32 @@
 
     def test_canonical_path(self):
         work_tree = self._make_canonical_test_tree()
-        if not isinstance(work_tree, InventoryTree):
-            raise tests.TestNotApplicable(
-                "test not applicable on non-inventory tests")
         self.assertEqual('dir/file',
                          work_tree.get_canonical_inventory_path('Dir/File'))
 
     def test_canonical_path_before_commit(self):
         work_tree = self._make_canonical_test_tree(False)
-        if not isinstance(work_tree, InventoryTree):
-            raise tests.TestNotApplicable(
-                "test not applicable on non-inventory tests")        # note: not committed.
+        # note: not committed.
         self.assertEqual('dir/file',
                          work_tree.get_canonical_inventory_path('Dir/File'))
 
     def test_canonical_path_dir(self):
         # check it works when asked for just the directory portion.
         work_tree = self._make_canonical_test_tree()
-        if not isinstance(work_tree, InventoryTree):
-            raise tests.TestNotApplicable(
-                "test not applicable on non-inventory tests")
         self.assertEqual('dir', work_tree.get_canonical_inventory_path('Dir'))
 
     def test_canonical_path_root(self):
         work_tree = self._make_canonical_test_tree()
-        if not isinstance(work_tree, InventoryTree):
-            raise tests.TestNotApplicable(
-                "test not applicable on non-inventory tests")
         self.assertEqual('', work_tree.get_canonical_inventory_path(''))
         self.assertEqual('/', work_tree.get_canonical_inventory_path('/'))
 
     def test_canonical_path_invalid_all(self):
         work_tree = self._make_canonical_test_tree()
-        if not isinstance(work_tree, InventoryTree):
-            raise tests.TestNotApplicable(
-                "test not applicable on non-inventory tests")
         self.assertEqual('foo/bar',
                          work_tree.get_canonical_inventory_path('foo/bar'))
 
     def test_canonical_invalid_child(self):
         work_tree = self._make_canonical_test_tree()
-        if not isinstance(work_tree, InventoryTree):
-            raise tests.TestNotApplicable(
-                "test not applicable on non-inventory tests")
         self.assertEqual('dir/None',
                          work_tree.get_canonical_inventory_path('Dir/None'))
 
@@ -194,9 +176,6 @@
         work_tree.add(['test/', 'test/file', 'Test'])
 
         test_tree = self._convert_tree(work_tree)
-        if not isinstance(test_tree, InventoryTree):
-            raise tests.TestNotApplicable(
-                "test not applicable on non-inventory tests")
         test_tree.lock_read()
         self.addCleanup(test_tree.unlock)
 

=== modified file 'bzrlib/tests/per_workingtree/__init__.py'
--- bzrlib/tests/per_workingtree/__init__.py	2011-05-04 11:15:37 +0000
+++ bzrlib/tests/per_workingtree/__init__.py	2011-02-24 16:45:27 +0000
@@ -24,6 +24,7 @@
 
 from bzrlib import (
     branchbuilder,
+    errors,
     tests,
     workingtree,
     )

=== modified file 'bzrlib/tests/per_workingtree/test_break_lock.py'
--- bzrlib/tests/per_workingtree/test_break_lock.py	2011-05-04 11:15:37 +0000
+++ bzrlib/tests/per_workingtree/test_break_lock.py	2010-01-25 17:48:22 +0000
@@ -15,6 +15,9 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
+from cStringIO import StringIO
+import os
+
 from bzrlib import (
     errors,
     ui,

=== modified file 'bzrlib/tests/per_workingtree/test_is_control_filename.py'
--- bzrlib/tests/per_workingtree/test_is_control_filename.py	2011-05-04 11:15:37 +0000
+++ bzrlib/tests/per_workingtree/test_is_control_filename.py	2009-07-10 07:14:02 +0000
@@ -15,6 +15,8 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
+import os
+
 from bzrlib.osutils import basename
 from bzrlib.tests.per_workingtree import TestCaseWithWorkingTree
 

=== modified file 'bzrlib/tests/per_workingtree/test_is_ignored.py'
--- bzrlib/tests/per_workingtree/test_is_ignored.py	2011-05-04 11:15:37 +0000
+++ bzrlib/tests/per_workingtree/test_is_ignored.py	2010-07-08 13:00:19 +0000
@@ -15,7 +15,8 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-from bzrlib import config, ignores
+import bzrlib
+from bzrlib import config, ignores, osutils
 from bzrlib.tests.per_workingtree import TestCaseWithWorkingTree
 
 

=== modified file 'bzrlib/tests/per_workingtree/test_locking.py'
--- bzrlib/tests/per_workingtree/test_locking.py	2011-05-04 11:15:37 +0000
+++ bzrlib/tests/per_workingtree/test_locking.py	2010-05-11 14:14:55 +0000
@@ -21,6 +21,7 @@
 from bzrlib import (
     branch,
     errors,
+    lockdir,
     )
 from bzrlib.tests import TestSkipped
 from bzrlib.tests.matchers import *

=== modified file 'bzrlib/tests/per_workingtree/test_move.py'
--- bzrlib/tests/per_workingtree/test_move.py	2011-05-04 11:15:37 +0000
+++ bzrlib/tests/per_workingtree/test_move.py	2011-04-15 07:01:22 +0000
@@ -24,6 +24,7 @@
     tests,
     )
 
+from bzrlib.workingtree_4 import DirStateWorkingTreeFormat
 from bzrlib.tests.per_workingtree import TestCaseWithWorkingTree
 
 

=== modified file 'bzrlib/tests/per_workingtree/test_readonly.py'
--- bzrlib/tests/per_workingtree/test_readonly.py	2011-05-04 11:15:37 +0000
+++ bzrlib/tests/per_workingtree/test_readonly.py	2010-01-25 15:55:48 +0000
@@ -21,6 +21,7 @@
 import time
 
 from bzrlib import (
+    errors,
     hashcache,
     tests,
     )

=== modified file 'bzrlib/tests/per_workingtree/test_remove.py'
--- bzrlib/tests/per_workingtree/test_remove.py	2011-05-04 11:15:37 +0000
+++ bzrlib/tests/per_workingtree/test_remove.py	2011-04-15 07:01:22 +0000
@@ -17,7 +17,7 @@
 """Tests for interface conformance of 'WorkingTree.remove'"""
 
 from bzrlib.tests.per_workingtree import TestCaseWithWorkingTree
-from bzrlib import ignores, osutils
+from bzrlib import errors, ignores, osutils
 
 class TestRemove(TestCaseWithWorkingTree):
     """Tests WorkingTree.remove"""

=== modified file 'bzrlib/tests/per_workingtree/test_revision_tree.py'
--- bzrlib/tests/per_workingtree/test_revision_tree.py	2011-05-04 11:15:37 +0000
+++ bzrlib/tests/per_workingtree/test_revision_tree.py	2010-03-10 09:33:04 +0000
@@ -24,6 +24,7 @@
 """
 
 from bzrlib import (
+    branchbuilder,
     errors,
     tests,
     )

=== modified file 'bzrlib/tests/per_workingtree/test_smart_add.py'
--- bzrlib/tests/per_workingtree/test_smart_add.py	2011-05-04 21:10:36 +0000
+++ bzrlib/tests/per_workingtree/test_smart_add.py	2011-04-21 20:32:16 +0000
@@ -21,10 +21,12 @@
 import sys
 
 from bzrlib import (
+    add,
     errors,
     ignores,
     osutils,
     tests,
+    workingtree,
     )
 from bzrlib.tests import (
     test_smart_add,

=== modified file 'bzrlib/tests/per_workingtree/test_symlinks.py'
--- bzrlib/tests/per_workingtree/test_symlinks.py	2011-05-04 11:15:37 +0000
+++ bzrlib/tests/per_workingtree/test_symlinks.py	2010-08-17 06:45:33 +0000
@@ -20,6 +20,7 @@
 import os
 
 from bzrlib import (
+    builtins,
     osutils,
     tests,
     workingtree,

=== modified file 'bzrlib/tests/per_workingtree/test_uncommit.py'
--- bzrlib/tests/per_workingtree/test_uncommit.py	2011-05-04 11:15:37 +0000
+++ bzrlib/tests/per_workingtree/test_uncommit.py	2009-07-10 07:14:02 +0000
@@ -16,7 +16,12 @@
 
 """Tests of the parent related functions of WorkingTrees."""
 
+import os
+
 from bzrlib import (
+    errors,
+    revision as _mod_revision,
+    symbol_versioning,
     uncommit,
     )
 from bzrlib.tests.per_workingtree import TestCaseWithWorkingTree

=== modified file 'bzrlib/tests/per_workingtree/test_unversion.py'
--- bzrlib/tests/per_workingtree/test_unversion.py	2011-05-04 11:15:37 +0000
+++ bzrlib/tests/per_workingtree/test_unversion.py	2010-11-05 20:54:32 +0000
@@ -18,6 +18,7 @@
 
 from bzrlib import (
     errors,
+    osutils,
     )
 from bzrlib.tests.per_workingtree import TestCaseWithWorkingTree
 

=== modified file 'bzrlib/tests/test_annotate.py'
--- bzrlib/tests/test_annotate.py	2011-05-03 13:53:46 +0000
+++ bzrlib/tests/test_annotate.py	2011-01-12 01:01:53 +0000
@@ -21,7 +21,6 @@
 
 from bzrlib import (
     annotate,
-    symbol_versioning,
     tests,
     )
 
@@ -261,26 +260,15 @@
             ('modify', ('file-id', e_text))])
         return builder
 
-    def assertAnnotateEqualDiff(self, actual, expected):
+    def assertRepoAnnotate(self, expected, repo, file_id, revision_id):
+        """Assert that the revision is properly annotated."""
+        actual = list(repo.revision_tree(revision_id).annotate_iter(file_id))
         if actual != expected:
             # Create an easier to understand diff when the lines don't actually
             # match
             self.assertEqualDiff(''.join('\t'.join(l) for l in expected),
                                  ''.join('\t'.join(l) for l in actual))
 
-    def assertBranchAnnotate(self, expected, branch, file_id, revision_id,
-            verbose=False, full=False, show_ids=False):
-        tree = branch.repository.revision_tree(revision_id)
-        to_file = StringIO()
-        annotate.annotate_file_tree(tree, file_id, to_file,
-            verbose=verbose, full=full, show_ids=show_ids, branch=branch)
-        self.assertAnnotateEqualDiff(to_file.getvalue(), expected)
-
-    def assertRepoAnnotate(self, expected, repo, file_id, revision_id):
-        """Assert that the revision is properly annotated."""
-        actual = list(repo.revision_tree(revision_id).annotate_iter(file_id))
-        self.assertAnnotateEqualDiff(actual, expected)
-
     def test_annotate_duplicate_lines(self):
         # XXX: Should this be a per_repository test?
         builder = self.create_duplicate_lines_tree()
@@ -297,64 +285,62 @@
     def test_annotate_shows_dotted_revnos(self):
         builder = self.create_merged_trees()
 
-        self.assertBranchAnnotate('1     joe@foo | first\n'
-                                  '2     joe@foo | second\n'
-                                  '1.1.1 barry@f | third\n',
-                                  builder.get_branch(), 'a-id', 'rev-3')
-
-    def test_annotate_file(self):
-        builder = self.create_merged_trees()
-
-        to_file = StringIO()
-        self.applyDeprecated(symbol_versioning.deprecated_in((2, 4, 0)),
-            annotate.annotate_file, builder.get_branch(),
-                'rev-3', 'a-id', to_file=to_file)
-
-        self.assertAnnotateEqualDiff('1     joe@foo | first\n'
-                                     '2     joe@foo | second\n'
-                                     '1.1.1 barry@f | third\n',
-                                     to_file.getvalue())
+        sio = StringIO()
+        annotate.annotate_file(builder.get_branch(), 'rev-3', 'a-id',
+                               to_file=sio)
+        self.assertEqualDiff('1     joe@foo | first\n'
+                             '2     joe@foo | second\n'
+                             '1.1.1 barry@f | third\n',
+                             sio.getvalue())
 
     def test_annotate_limits_dotted_revnos(self):
         """Annotate should limit dotted revnos to a depth of 12"""
         builder = self.create_deeply_merged_trees()
 
-        self.assertBranchAnnotate('1     joe@foo | first\n'
-                                  '2     joe@foo | second\n'
-                                  '1.1.1 barry@f | third\n'
-                                  '1.2.1 jerry@f | fourth\n'
-                                  '1.3.1 george@ | fifth\n'
-                                  '              | sixth\n',
-                                  builder.get_branch(), 'a-id', 'rev-6',
-                                  verbose=False, full=False)
+        sio = StringIO()
+        annotate.annotate_file(builder.get_branch(), 'rev-6', 'a-id',
+                               to_file=sio, verbose=False, full=False)
+        self.assertEqualDiff('1     joe@foo | first\n'
+                             '2     joe@foo | second\n'
+                             '1.1.1 barry@f | third\n'
+                             '1.2.1 jerry@f | fourth\n'
+                             '1.3.1 george@ | fifth\n'
+                             '              | sixth\n',
+                             sio.getvalue())
 
-        self.assertBranchAnnotate('1     joe@foo | first\n'
-                                  '2     joe@foo | second\n'
-                                  '1.1.1 barry@f | third\n'
-                                  '1.2.1 jerry@f | fourth\n'
-                                  '1.3.1 george@ | fifth\n'
-                                  '1.3.1 george@ | sixth\n',
-                                  builder.get_branch(), 'a-id', 'rev-6',
-                                  verbose=False, full=True)
+        sio = StringIO()
+        annotate.annotate_file(builder.get_branch(), 'rev-6', 'a-id',
+                               to_file=sio, verbose=False, full=True)
+        self.assertEqualDiff('1     joe@foo | first\n'
+                             '2     joe@foo | second\n'
+                             '1.1.1 barry@f | third\n'
+                             '1.2.1 jerry@f | fourth\n'
+                             '1.3.1 george@ | fifth\n'
+                             '1.3.1 george@ | sixth\n',
+                             sio.getvalue())
 
         # verbose=True shows everything, the full revno, user id, and date
-        self.assertBranchAnnotate('1     joe@foo.com    20061213 | first\n'
-                                  '2     joe@foo.com    20061213 | second\n'
-                                  '1.1.1 barry@foo.com  20061213 | third\n'
-                                  '1.2.1 jerry@foo.com  20061213 | fourth\n'
-                                  '1.3.1 george@foo.com 20061213 | fifth\n'
-                                  '                              | sixth\n',
-                                  builder.get_branch(), 'a-id', 'rev-6',
-                                  verbose=True, full=False)
+        sio = StringIO()
+        annotate.annotate_file(builder.get_branch(), 'rev-6', 'a-id',
+                               to_file=sio, verbose=True, full=False)
+        self.assertEqualDiff('1     joe@foo.com    20061213 | first\n'
+                             '2     joe@foo.com    20061213 | second\n'
+                             '1.1.1 barry@foo.com  20061213 | third\n'
+                             '1.2.1 jerry@foo.com  20061213 | fourth\n'
+                             '1.3.1 george@foo.com 20061213 | fifth\n'
+                             '                              | sixth\n',
+                             sio.getvalue())
 
-        self.assertBranchAnnotate('1     joe@foo.com    20061213 | first\n'
-                                  '2     joe@foo.com    20061213 | second\n'
-                                  '1.1.1 barry@foo.com  20061213 | third\n'
-                                  '1.2.1 jerry@foo.com  20061213 | fourth\n'
-                                  '1.3.1 george@foo.com 20061213 | fifth\n'
-                                  '1.3.1 george@foo.com 20061213 | sixth\n',
-                                  builder.get_branch(), 'a-id', 'rev-6',
-                                  verbose=True, full=True)
+        sio = StringIO()
+        annotate.annotate_file(builder.get_branch(), 'rev-6', 'a-id',
+                               to_file=sio, verbose=True, full=True)
+        self.assertEqualDiff('1     joe@foo.com    20061213 | first\n'
+                             '2     joe@foo.com    20061213 | second\n'
+                             '1.1.1 barry@foo.com  20061213 | third\n'
+                             '1.2.1 jerry@foo.com  20061213 | fourth\n'
+                             '1.3.1 george@foo.com 20061213 | fifth\n'
+                             '1.3.1 george@foo.com 20061213 | sixth\n',
+                             sio.getvalue())
 
     def test_annotate_uses_branch_context(self):
         """Dotted revnos should use the Branch context.
@@ -364,35 +350,43 @@
         """
         builder = self.create_deeply_merged_trees()
 
-        self.assertBranchAnnotate('1     joe@foo | first\n'
-                                  '1.1.1 barry@f | third\n'
-                                  '1.2.1 jerry@f | fourth\n'
-                                  '1.3.1 george@ | fifth\n'
-                                  '              | sixth\n',
-                                  builder.get_branch(), 'a-id', 'rev-1_3_1',
-                                  verbose=False, full=False)
+        sio = StringIO()
+        annotate.annotate_file(builder.get_branch(), 'rev-1_3_1', 'a-id',
+                               to_file=sio, verbose=False, full=False)
+        self.assertEqualDiff('1     joe@foo | first\n'
+                             '1.1.1 barry@f | third\n'
+                             '1.2.1 jerry@f | fourth\n'
+                             '1.3.1 george@ | fifth\n'
+                             '              | sixth\n',
+                             sio.getvalue())
 
     def test_annotate_show_ids(self):
         builder = self.create_deeply_merged_trees()
 
+        sio = StringIO()
+        annotate.annotate_file(builder.get_branch(), 'rev-6', 'a-id',
+                               to_file=sio, show_ids=True, full=False)
+
         # It looks better with real revision ids :)
-        self.assertBranchAnnotate('    rev-1 | first\n'
-                                  '    rev-2 | second\n'
-                                  'rev-1_1_1 | third\n'
-                                  'rev-1_2_1 | fourth\n'
-                                  'rev-1_3_1 | fifth\n'
-                                  '          | sixth\n',
-                                  builder.get_branch(), 'a-id', 'rev-6',
-                                  show_ids=True, full=False)
-
-        self.assertBranchAnnotate('    rev-1 | first\n'
-                                  '    rev-2 | second\n'
-                                  'rev-1_1_1 | third\n'
-                                  'rev-1_2_1 | fourth\n'
-                                  'rev-1_3_1 | fifth\n'
-                                  'rev-1_3_1 | sixth\n',
-                                  builder.get_branch(), 'a-id', 'rev-6',
-                                  show_ids=True, full=True)
+        self.assertEqualDiff('    rev-1 | first\n'
+                             '    rev-2 | second\n'
+                             'rev-1_1_1 | third\n'
+                             'rev-1_2_1 | fourth\n'
+                             'rev-1_3_1 | fifth\n'
+                             '          | sixth\n',
+                             sio.getvalue())
+
+        sio = StringIO()
+        annotate.annotate_file(builder.get_branch(), 'rev-6', 'a-id',
+                               to_file=sio, show_ids=True, full=True)
+
+        self.assertEqualDiff('    rev-1 | first\n'
+                             '    rev-2 | second\n'
+                             'rev-1_1_1 | third\n'
+                             'rev-1_2_1 | fourth\n'
+                             'rev-1_3_1 | fifth\n'
+                             'rev-1_3_1 | sixth\n',
+                             sio.getvalue())
 
     def test_annotate_unicode_author(self):
         tree1 = self.make_branch_and_tree('tree1')
@@ -411,33 +405,25 @@
 
         tree1.lock_read()
         self.addCleanup(tree1.unlock)
-
-        revtree_1 = tree1.branch.repository.revision_tree('rev-1')
-        revtree_2 = tree1.branch.repository.revision_tree('rev-2')
-
         # this passes if no exception is raised
         to_file = StringIO()
-        annotate.annotate_file_tree(revtree_1, 'a-id',
-            to_file=to_file, branch=tree1.branch)
+        annotate.annotate_file(tree1.branch, 'rev-1', 'a-id', to_file=to_file)
 
         sio = StringIO()
         to_file = codecs.getwriter('ascii')(sio)
         to_file.encoding = 'ascii' # codecs does not set it
-        annotate.annotate_file_tree(revtree_2, 'b-id',
-            to_file=to_file, branch=tree1.branch)
+        annotate.annotate_file(tree1.branch, 'rev-2', 'b-id', to_file=to_file)
         self.assertEqualDiff('2   p?rez   | bye\n', sio.getvalue())
 
         # test now with to_file.encoding = None
         to_file = tests.StringIOWrapper()
         to_file.encoding = None
-        annotate.annotate_file_tree(revtree_2, 'b-id',
-            to_file=to_file, branch=tree1.branch)
+        annotate.annotate_file(tree1.branch, 'rev-2', 'b-id', to_file=to_file)
         self.assertContainsRe('2   p.rez   | bye\n', to_file.getvalue())
 
         # and when it does not exist
         to_file = StringIO()
-        annotate.annotate_file_tree(revtree_2, 'b-id',
-            to_file=to_file, branch=tree1.branch)
+        annotate.annotate_file(tree1.branch, 'rev-2', 'b-id', to_file=to_file)
         self.assertContainsRe('2   p.rez   | bye\n', to_file.getvalue())
 
     def test_annotate_author_or_committer(self):
@@ -458,13 +444,13 @@
 
         tree1.lock_read()
         self.addCleanup(tree1.unlock)
-
-        self.assertBranchAnnotate('1   committ | hello\n', tree1.branch,
-            'a-id', 'rev-1')
-
-        to_file = StringIO()
-        self.assertBranchAnnotate('2   author@ | bye\n', tree1.branch,
-            'b-id', 'rev-2')
+        to_file = StringIO()
+        annotate.annotate_file(tree1.branch, 'rev-1', 'a-id', to_file=to_file)
+        self.assertEqual('1   committ | hello\n', to_file.getvalue())
+
+        to_file = StringIO()
+        annotate.annotate_file(tree1.branch, 'rev-2', 'b-id', to_file=to_file)
+        self.assertEqual('2   author@ | bye\n', to_file.getvalue())
 
 
 class TestReannotate(tests.TestCase):

=== modified file 'bzrlib/tests/test_bzrdir.py'
--- bzrlib/tests/test_bzrdir.py	2011-05-05 01:58:00 +0000
+++ bzrlib/tests/test_bzrdir.py	2011-04-15 07:01:22 +0000
@@ -38,8 +38,7 @@
     transport as _mod_transport,
     urlutils,
     win32utils,
-    workingtree_3,
-    workingtree_4,
+    workingtree,
     )
 import bzrlib.branch
 from bzrlib.errors import (
@@ -808,7 +807,7 @@
         branch = self.make_branch('branch', format='knit')
         format = branch.bzrdir.cloning_metadir()
         self.assertIsInstance(format.workingtree_format,
-            workingtree_4.WorkingTreeFormat6)
+            workingtree.WorkingTreeFormat3)
 
     def test_sprout_recursive_treeless(self):
         tree = self.make_branch_and_tree('tree1',
@@ -964,7 +963,7 @@
         checkout_base = t.clone('checkout').base
         self.assertEqual(checkout_base, dir.get_workingtree_transport(None).base)
         self.assertEqual(checkout_base,
-                         dir.get_workingtree_transport(workingtree_3.WorkingTreeFormat3()).base)
+                         dir.get_workingtree_transport(workingtree.WorkingTreeFormat3()).base)
 
     def test_meta1dir_uses_lockdir(self):
         """Meta1 format uses a LockDir to guard the whole directory, not a file."""
@@ -1058,7 +1057,7 @@
         my_bzrdir = bzrdir.BzrDir.open(self.get_url('branch-knit2'))
         checkout_format = my_bzrdir.checkout_metadir()
         self.assertIsInstance(checkout_format.workingtree_format,
-                              workingtree_4.WorkingTreeFormat4)
+                              workingtree.WorkingTreeFormat3)
 
 
 class TestHTTPRedirections(object):

=== removed file 'bzrlib/tests/test_export_pot.py'
--- bzrlib/tests/test_export_pot.py	2011-05-11 17:44:45 +0000
+++ bzrlib/tests/test_export_pot.py	1970-01-01 00:00:00 +0000
@@ -1,147 +0,0 @@
-# Copyright (C) 2011 Canonical Ltd
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
-
-from cStringIO import StringIO
-import textwrap
-
-from bzrlib import (
-    export_pot,
-    tests,
-    )
-
-class TestEscape(tests.TestCase):
-
-    def test_simple_escape(self):
-        self.assertEqual(
-                export_pot._escape('foobar'),
-                'foobar')
-
-        s = '''foo\nbar\r\tbaz\\"spam"'''
-        e = '''foo\\nbar\\r\\tbaz\\\\\\"spam\\"'''
-        self.assertEqual(export_pot._escape(s), e)
-
-    def test_complex_escape(self):
-        s = '''\\r \\\n'''
-        e = '''\\\\r \\\\\\n'''
-        self.assertEqual(export_pot._escape(s), e)
-
-
-class TestNormalize(tests.TestCase):
-
-    def test_single_line(self):
-        s = 'foobar'
-        e = '"foobar"'
-        self.assertEqual(export_pot._normalize(s), e)
-
-        s = 'foo"bar'
-        e = '"foo\\"bar"'
-        self.assertEqual(export_pot._normalize(s), e)
-
-    def test_multi_lines(self):
-        s = 'foo\nbar\n'
-        e = '""\n"foo\\n"\n"bar\\n"'
-        self.assertEqual(export_pot._normalize(s), e)
-
-        s = '\nfoo\nbar\n'
-        e = ('""\n'
-             '"\\n"\n'
-             '"foo\\n"\n'
-             '"bar\\n"')
-        self.assertEqual(export_pot._normalize(s), e)
-
-
-class PoEntryTestCase(tests.TestCase):
-
-    def setUp(self):
-        self.overrideAttr(export_pot, '_FOUND_MSGID', set())
-        self._outf = StringIO()
-        super(PoEntryTestCase, self).setUp()
-
-    def check_output(self, expected):
-        self.assertEqual(
-                self._outf.getvalue(),
-                textwrap.dedent(expected)
-                )
-
-class TestPoEntry(PoEntryTestCase):
-
-    def test_simple(self):
-        export_pot._poentry(self._outf, 'dummy', 1, "spam")
-        export_pot._poentry(self._outf, 'dummy', 2, "ham", 'EGG')
-        self.check_output('''\
-                #: dummy:1
-                msgid "spam"
-                msgstr ""
-
-                #: dummy:2
-                # EGG
-                msgid "ham"
-                msgstr ""
-
-                ''')
-
-    def test_duplicate(self):
-        export_pot._poentry(self._outf, 'dummy', 1, "spam")
-        # This should be ignored.
-        export_pot._poentry(self._outf, 'dummy', 2, "spam", 'EGG')
-
-        self.check_output('''\
-                #: dummy:1
-                msgid "spam"
-                msgstr ""\n
-                ''')
-
-
-class TestPoentryPerPergraph(PoEntryTestCase):
-
-    def test_single(self):
-        export_pot._poentry_per_paragraph(
-                self._outf,
-                'dummy',
-                10,
-                '''foo\nbar\nbaz\n'''
-                )
-        self.check_output('''\
-                #: dummy:10
-                msgid ""
-                "foo\\n"
-                "bar\\n"
-                "baz\\n"
-                msgstr ""\n
-                ''')
-
-    def test_multi(self):
-        export_pot._poentry_per_paragraph(
-                self._outf,
-                'dummy',
-                10,
-                '''spam\nham\negg\n\nSPAM\nHAM\nEGG\n'''
-                )
-        self.check_output('''\
-                #: dummy:10
-                msgid ""
-                "spam\\n"
-                "ham\\n"
-                "egg"
-                msgstr ""
-
-                #: dummy:14
-                msgid ""
-                "SPAM\\n"
-                "HAM\\n"
-                "EGG\\n"
-                msgstr ""\n
-                ''')

=== modified file 'bzrlib/tests/test_selftest.py'
--- bzrlib/tests/test_selftest.py	2011-05-05 01:58:00 +0000
+++ bzrlib/tests/test_selftest.py	2011-05-04 16:17:27 +0000
@@ -52,7 +52,6 @@
     tests,
     transport,
     workingtree,
-    workingtree_3,
     workingtree_4,
     )
 from bzrlib.repofmt import (
@@ -341,7 +340,7 @@
         server1 = "a"
         server2 = "b"
         formats = [workingtree_4.WorkingTreeFormat4(),
-                   workingtree_3.WorkingTreeFormat3(),]
+                   workingtree.WorkingTreeFormat3(),]
         scenarios = make_scenarios(server1, server2, formats)
         self.assertEqual([
             ('WorkingTreeFormat4',
@@ -378,7 +377,7 @@
         server1 = "a"
         server2 = "b"
         formats = [workingtree_4.WorkingTreeFormat4(),
-                   workingtree_3.WorkingTreeFormat3(),]
+                   workingtree.WorkingTreeFormat3(),]
         scenarios = make_scenarios(server1, server2, formats)
         self.assertEqual(7, len(scenarios))
         default_wt_format = workingtree.format_registry.get_default()
@@ -455,7 +454,7 @@
         from bzrlib.tests.per_intertree import (
             make_scenarios,
             )
-        from bzrlib.workingtree_3 import WorkingTreeFormat3
+        from bzrlib.workingtree import WorkingTreeFormat3
         from bzrlib.workingtree_4 import WorkingTreeFormat4
         input_test = TestInterTreeScenarios(
             "test_scenarios")

=== modified file 'bzrlib/tests/test_workingtree.py'
--- bzrlib/tests/test_workingtree.py	2011-05-05 01:58:00 +0000
+++ bzrlib/tests/test_workingtree.py	2011-05-03 23:16:56 +0000
@@ -22,8 +22,6 @@
     symbol_versioning,
     transport,
     workingtree,
-    workingtree_3,
-    workingtree_4,
     )
 from bzrlib.lockdir import LockDir
 from bzrlib.mutabletree import needs_tree_write_lock
@@ -64,8 +62,8 @@
 
     def test_get_set_default_format(self):
         old_format = workingtree.format_registry.get_default()
-        # default is 6
-        self.assertTrue(isinstance(old_format, workingtree_4.WorkingTreeFormat6))
+        # default is 3
+        self.assertTrue(isinstance(old_format, workingtree.WorkingTreeFormat3))
         workingtree.format_registry.set_default(SampleTreeFormat())
         try:
             # the default branch format is used by the meta dir format
@@ -81,11 +79,11 @@
 
     def test_get_set_default_format_by_key(self):
         old_format = workingtree.format_registry.get_default()
-        # default is 6
+        # default is 3
         format = SampleTreeFormat()
         workingtree.format_registry.register(format)
         self.addCleanup(workingtree.format_registry.remove, format)
-        self.assertTrue(isinstance(old_format, workingtree_4.WorkingTreeFormat6))
+        self.assertTrue(isinstance(old_format, workingtree.WorkingTreeFormat3))
         workingtree.format_registry.set_default_key(format.get_format_string())
         try:
             # the default branch format is used by the meta dir format
@@ -193,7 +191,7 @@
             t = transport.get_transport(url)
             found_format = workingtree.WorkingTreeFormat.find_format(dir)
             self.assertIsInstance(found_format, format.__class__)
-        check_format(workingtree_3.WorkingTreeFormat3(), "bar")
+        check_format(workingtree.WorkingTreeFormat3(), "bar")
 
     def test_find_format_no_tree(self):
         dir = bzrdir.BzrDirMetaFormat1().initialize('.')
@@ -277,7 +275,7 @@
         control = bzrdir.BzrDirMetaFormat1().initialize(self.get_url())
         control.create_repository()
         control.create_branch()
-        tree = workingtree_3.WorkingTreeFormat3().initialize(control)
+        tree = workingtree.WorkingTreeFormat3().initialize(control)
         # we want:
         # format 'Bazaar-NG Working Tree format 3'
         # inventory = blank inventory
@@ -311,7 +309,7 @@
         repo = dir.create_repository()
         branch = dir.create_branch()
         try:
-            tree = workingtree_3.WorkingTreeFormat3().initialize(dir)
+            tree = workingtree.WorkingTreeFormat3().initialize(dir)
         except errors.NotLocalUrl:
             raise TestSkipped('Not a local URL')
         self.assertIsDirectory('.bzr', t)
@@ -328,7 +326,7 @@
         control = bzrdir.BzrDirMetaFormat1().initialize(self.get_url())
         control.create_repository()
         control.create_branch()
-        tree = workingtree_3.WorkingTreeFormat3().initialize(control)
+        tree = workingtree.WorkingTreeFormat3().initialize(control)
         tree._transport.delete("pending-merges")
         self.assertEqual([], tree.get_parent_ids())
 

=== modified file 'bzrlib/workingtree.py'
--- bzrlib/workingtree.py	2011-05-04 22:23:20 +0000
+++ bzrlib/workingtree.py	2011-05-04 16:17:27 +0000
@@ -73,6 +73,8 @@
 from bzrlib import symbol_versioning
 from bzrlib.decorators import needs_read_lock, needs_write_lock
 from bzrlib.lock import LogicalLockResult
+from bzrlib.lockable_files import LockableFiles
+from bzrlib.lockdir import LockDir
 import bzrlib.mutabletree
 from bzrlib.mutabletree import needs_tree_write_lock
 from bzrlib import osutils
@@ -87,6 +89,7 @@
     supports_executable,
     )
 from bzrlib.trace import mutter, note
+from bzrlib.transport.local import LocalTransport
 from bzrlib.revision import CURRENT_REVISION
 from bzrlib.symbol_versioning import (
     deprecated_passed,
@@ -2012,35 +2015,6 @@
         inventory.revision_id = revision_id
         return xml7.serializer_v7.write_inventory_to_string(inventory)
 
-    @needs_tree_write_lock
-    def set_conflicts(self, conflicts):
-        self._put_rio('conflicts', conflicts.to_stanzas(),
-                      CONFLICT_HEADER_1)
-
-    @needs_tree_write_lock
-    def add_conflicts(self, new_conflicts):
-        conflict_set = set(self.conflicts())
-        conflict_set.update(set(list(new_conflicts)))
-        self.set_conflicts(_mod_conflicts.ConflictList(sorted(conflict_set,
-                                       key=_mod_conflicts.Conflict.sort_key)))
-
-    @needs_read_lock
-    def conflicts(self):
-        try:
-            confile = self._transport.get('conflicts')
-        except errors.NoSuchFile:
-            return _mod_conflicts.ConflictList()
-        try:
-            try:
-                if confile.next() != CONFLICT_HEADER_1 + '\n':
-                    raise errors.ConflictFormatError()
-            except StopIteration:
-                raise errors.ConflictFormatError()
-            reader = _mod_rio.RioReader(confile)
-            return _mod_conflicts.ConflictList.from_stanzas(reader)
-        finally:
-            confile.close()
-
     def read_basis_inventory(self):
         """Read the cached basis inventory."""
         path = self._basis_inventory_name()
@@ -2909,6 +2883,85 @@
                     pending.append(dir)
 
 
+class WorkingTree3(InventoryWorkingTree):
+    """This is the Format 3 working tree.
+
+    This differs from the base WorkingTree by:
+     - having its own file lock
+     - having its own last-revision property.
+
+    This is new in bzr 0.8
+    """
+
+    @needs_read_lock
+    def _last_revision(self):
+        """See Mutable.last_revision."""
+        try:
+            return self._transport.get_bytes('last-revision')
+        except errors.NoSuchFile:
+            return _mod_revision.NULL_REVISION
+
+    def _change_last_revision(self, revision_id):
+        """See WorkingTree._change_last_revision."""
+        if revision_id is None or revision_id == _mod_revision.NULL_REVISION:
+            try:
+                self._transport.delete('last-revision')
+            except errors.NoSuchFile:
+                pass
+            return False
+        else:
+            self._transport.put_bytes('last-revision', revision_id,
+                mode=self.bzrdir._get_file_mode())
+            return True
+
+    def _get_check_refs(self):
+        """Return the references needed to perform a check of this tree."""
+        return [('trees', self.last_revision())]
+
+    @needs_tree_write_lock
+    def set_conflicts(self, conflicts):
+        self._put_rio('conflicts', conflicts.to_stanzas(),
+                      CONFLICT_HEADER_1)
+
+    @needs_tree_write_lock
+    def add_conflicts(self, new_conflicts):
+        conflict_set = set(self.conflicts())
+        conflict_set.update(set(list(new_conflicts)))
+        self.set_conflicts(_mod_conflicts.ConflictList(sorted(conflict_set,
+                                       key=_mod_conflicts.Conflict.sort_key)))
+
+    @needs_read_lock
+    def conflicts(self):
+        try:
+            confile = self._transport.get('conflicts')
+        except errors.NoSuchFile:
+            return _mod_conflicts.ConflictList()
+        try:
+            try:
+                if confile.next() != CONFLICT_HEADER_1 + '\n':
+                    raise errors.ConflictFormatError()
+            except StopIteration:
+                raise errors.ConflictFormatError()
+            reader = _mod_rio.RioReader(confile)
+            return _mod_conflicts.ConflictList.from_stanzas(reader)
+        finally:
+            confile.close()
+
+    def unlock(self):
+        # do non-implementation specific cleanup
+        self._cleanup()
+        if self._control_files._lock_count == 1:
+            # _inventory_is_modified is always False during a read lock.
+            if self._inventory_is_modified:
+                self.flush()
+            self._write_hashcache_if_dirty()
+        # reverse order of locking.
+        try:
+            return self._control_files.unlock()
+        finally:
+            self.branch.unlock()
+
+
 class WorkingTreeFormatRegistry(controldir.ControlComponentFormatRegistry):
     """Registry for working tree formats."""
 
@@ -3078,12 +3131,144 @@
         format_registry.remove(format)
 
 
+class WorkingTreeFormat3(WorkingTreeFormat):
+    """The second working tree format updated to record a format marker.
+
+    This format:
+        - exists within a metadir controlling .bzr
+        - includes an explicit version marker for the workingtree control
+          files, separate from the BzrDir format
+        - modifies the hash cache format
+        - is new in bzr 0.8
+        - uses a LockDir to guard access for writes.
+    """
+
+    upgrade_recommended = True
+
+    missing_parent_conflicts = True
+
+    def get_format_string(self):
+        """See WorkingTreeFormat.get_format_string()."""
+        return "Bazaar-NG Working Tree format 3"
+
+    def get_format_description(self):
+        """See WorkingTreeFormat.get_format_description()."""
+        return "Working tree format 3"
+
+    _lock_file_name = 'lock'
+    _lock_class = LockDir
+
+    _tree_class = WorkingTree3
+
+    def __get_matchingbzrdir(self):
+        return bzrdir.BzrDirMetaFormat1()
+
+    _matchingbzrdir = property(__get_matchingbzrdir)
+
+    def _open_control_files(self, a_bzrdir):
+        transport = a_bzrdir.get_workingtree_transport(None)
+        return LockableFiles(transport, self._lock_file_name,
+                             self._lock_class)
+
+    def initialize(self, a_bzrdir, revision_id=None, from_branch=None,
+                   accelerator_tree=None, hardlink=False):
+        """See WorkingTreeFormat.initialize().
+
+        :param revision_id: if supplied, create a working tree at a different
+            revision than the branch is at.
+        :param accelerator_tree: A tree which can be used for retrieving file
+            contents more quickly than the revision tree, i.e. a workingtree.
+            The revision tree will be used for cases where accelerator_tree's
+            content is different.
+        :param hardlink: If true, hard-link files from accelerator_tree,
+            where possible.
+        """
+        if not isinstance(a_bzrdir.transport, LocalTransport):
+            raise errors.NotLocalUrl(a_bzrdir.transport.base)
+        transport = a_bzrdir.get_workingtree_transport(self)
+        control_files = self._open_control_files(a_bzrdir)
+        control_files.create_lock()
+        control_files.lock_write()
+        transport.put_bytes('format', self.get_format_string(),
+            mode=a_bzrdir._get_file_mode())
+        if from_branch is not None:
+            branch = from_branch
+        else:
+            branch = a_bzrdir.open_branch()
+        if revision_id is None:
+            revision_id = _mod_revision.ensure_null(branch.last_revision())
+        # WorkingTree3 can handle an inventory which has a unique root id.
+        # as of bzr 0.12. However, bzr 0.11 and earlier fail to handle
+        # those trees. And because there isn't a format bump inbetween, we
+        # are maintaining compatibility with older clients.
+        # inv = Inventory(root_id=gen_root_id())
+        inv = self._initial_inventory()
+        wt = self._tree_class(a_bzrdir.root_transport.local_abspath('.'),
+                         branch,
+                         inv,
+                         _internal=True,
+                         _format=self,
+                         _bzrdir=a_bzrdir,
+                         _control_files=control_files)
+        wt.lock_tree_write()
+        try:
+            basis_tree = branch.repository.revision_tree(revision_id)
+            # only set an explicit root id if there is one to set.
+            if basis_tree.inventory.root is not None:
+                wt.set_root_id(basis_tree.get_root_id())
+            if revision_id == _mod_revision.NULL_REVISION:
+                wt.set_parent_trees([])
+            else:
+                wt.set_parent_trees([(revision_id, basis_tree)])
+            transform.build_tree(basis_tree, wt)
+        finally:
+            # Unlock in this order so that the unlock-triggers-flush in
+            # WorkingTree is given a chance to fire.
+            control_files.unlock()
+            wt.unlock()
+        return wt
+
+    def _initial_inventory(self):
+        return inventory.Inventory()
+
+    def __init__(self):
+        super(WorkingTreeFormat3, self).__init__()
+
+    def open(self, a_bzrdir, _found=False):
+        """Return the WorkingTree object for a_bzrdir
+
+        _found is a private parameter, do not use it. It is used to indicate
+               if format probing has already been done.
+        """
+        if not _found:
+            # we are being called directly and must probe.
+            raise NotImplementedError
+        if not isinstance(a_bzrdir.transport, LocalTransport):
+            raise errors.NotLocalUrl(a_bzrdir.transport.base)
+        wt = self._open(a_bzrdir, self._open_control_files(a_bzrdir))
+        return wt
+
+    def _open(self, a_bzrdir, control_files):
+        """Open the tree itself.
+
+        :param a_bzrdir: the dir for the tree.
+        :param control_files: the control files for the tree.
+        """
+        return self._tree_class(a_bzrdir.root_transport.local_abspath('.'),
+                                _internal=True,
+                                _format=self,
+                                _bzrdir=a_bzrdir,
+                                _control_files=control_files)
+
+    def __str__(self):
+        return self.get_format_string()
+
+
 format_registry.register_lazy("Bazaar Working Tree Format 4 (bzr 0.15)\n",
     "bzrlib.workingtree_4", "WorkingTreeFormat4")
 format_registry.register_lazy("Bazaar Working Tree Format 5 (bzr 1.11)\n",
     "bzrlib.workingtree_4", "WorkingTreeFormat5")
 format_registry.register_lazy("Bazaar Working Tree Format 6 (bzr 1.14)\n",
     "bzrlib.workingtree_4", "WorkingTreeFormat6")
-format_registry.register_lazy("Bazaar-NG Working Tree format 3",
-    "bzrlib.workingtree_3", "WorkingTreeFormat3")
+format_registry.register(WorkingTreeFormat3())
 format_registry.set_default_key("Bazaar Working Tree Format 6 (bzr 1.14)\n")

=== removed file 'bzrlib/workingtree_3.py'
--- bzrlib/workingtree_3.py	2011-05-03 23:54:46 +0000
+++ bzrlib/workingtree_3.py	1970-01-01 00:00:00 +0000
@@ -1,212 +0,0 @@
-# Copyright (C) 2007-2011 Canonical Ltd
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
-
-"""WorkingTree3 format and implementation.
-
-"""
-
-from bzrlib import (
-    bzrdir,
-    errors,
-    inventory,
-    revision as _mod_revision,
-    transform,
-    )
-from bzrlib.decorators import (
-    needs_read_lock,
-    )
-from bzrlib.lockable_files import LockableFiles
-from bzrlib.lockdir import LockDir
-from bzrlib.transport.local import LocalTransport
-from bzrlib.workingtree import (
-    InventoryWorkingTree,
-    WorkingTreeFormat,
-    )
-
-class WorkingTree3(InventoryWorkingTree):
-    """This is the Format 3 working tree.
-
-    This differs from the base WorkingTree by:
-     - having its own file lock
-     - having its own last-revision property.
-
-    This is new in bzr 0.8
-    """
-
-    @needs_read_lock
-    def _last_revision(self):
-        """See Mutable.last_revision."""
-        try:
-            return self._transport.get_bytes('last-revision')
-        except errors.NoSuchFile:
-            return _mod_revision.NULL_REVISION
-
-    def _change_last_revision(self, revision_id):
-        """See WorkingTree._change_last_revision."""
-        if revision_id is None or revision_id == _mod_revision.NULL_REVISION:
-            try:
-                self._transport.delete('last-revision')
-            except errors.NoSuchFile:
-                pass
-            return False
-        else:
-            self._transport.put_bytes('last-revision', revision_id,
-                mode=self.bzrdir._get_file_mode())
-            return True
-
-    def _get_check_refs(self):
-        """Return the references needed to perform a check of this tree."""
-        return [('trees', self.last_revision())]
-
-    def unlock(self):
-        # do non-implementation specific cleanup
-        self._cleanup()
-        if self._control_files._lock_count == 1:
-            # _inventory_is_modified is always False during a read lock.
-            if self._inventory_is_modified:
-                self.flush()
-            self._write_hashcache_if_dirty()
-        # reverse order of locking.
-        try:
-            return self._control_files.unlock()
-        finally:
-            self.branch.unlock()
-
-
-class WorkingTreeFormat3(WorkingTreeFormat):
-    """The second working tree format updated to record a format marker.
-
-    This format:
-        - exists within a metadir controlling .bzr
-        - includes an explicit version marker for the workingtree control
-          files, separate from the BzrDir format
-        - modifies the hash cache format
-        - is new in bzr 0.8
-        - uses a LockDir to guard access for writes.
-    """
-
-    upgrade_recommended = True
-
-    missing_parent_conflicts = True
-
-    def get_format_string(self):
-        """See WorkingTreeFormat.get_format_string()."""
-        return "Bazaar-NG Working Tree format 3"
-
-    def get_format_description(self):
-        """See WorkingTreeFormat.get_format_description()."""
-        return "Working tree format 3"
-
-    _tree_class = WorkingTree3
-
-    def __get_matchingbzrdir(self):
-        return bzrdir.BzrDirMetaFormat1()
-
-    _matchingbzrdir = property(__get_matchingbzrdir)
-
-    def _open_control_files(self, a_bzrdir):
-        transport = a_bzrdir.get_workingtree_transport(None)
-        return LockableFiles(transport, 'lock', LockDir)
-
-    def initialize(self, a_bzrdir, revision_id=None, from_branch=None,
-                   accelerator_tree=None, hardlink=False):
-        """See WorkingTreeFormat.initialize().
-
-        :param revision_id: if supplied, create a working tree at a different
-            revision than the branch is at.
-        :param accelerator_tree: A tree which can be used for retrieving file
-            contents more quickly than the revision tree, i.e. a workingtree.
-            The revision tree will be used for cases where accelerator_tree's
-            content is different.
-        :param hardlink: If true, hard-link files from accelerator_tree,
-            where possible.
-        """
-        if not isinstance(a_bzrdir.transport, LocalTransport):
-            raise errors.NotLocalUrl(a_bzrdir.transport.base)
-        transport = a_bzrdir.get_workingtree_transport(self)
-        control_files = self._open_control_files(a_bzrdir)
-        control_files.create_lock()
-        control_files.lock_write()
-        transport.put_bytes('format', self.get_format_string(),
-            mode=a_bzrdir._get_file_mode())
-        if from_branch is not None:
-            branch = from_branch
-        else:
-            branch = a_bzrdir.open_branch()
-        if revision_id is None:
-            revision_id = _mod_revision.ensure_null(branch.last_revision())
-        # WorkingTree3 can handle an inventory which has a unique root id.
-        # as of bzr 0.12. However, bzr 0.11 and earlier fail to handle
-        # those trees. And because there isn't a format bump inbetween, we
-        # are maintaining compatibility with older clients.
-        # inv = Inventory(root_id=gen_root_id())
-        inv = self._initial_inventory()
-        wt = self._tree_class(a_bzrdir.root_transport.local_abspath('.'),
-                         branch,
-                         inv,
-                         _internal=True,
-                         _format=self,
-                         _bzrdir=a_bzrdir,
-                         _control_files=control_files)
-        wt.lock_tree_write()
-        try:
-            basis_tree = branch.repository.revision_tree(revision_id)
-            # only set an explicit root id if there is one to set.
-            if basis_tree.inventory.root is not None:
-                wt.set_root_id(basis_tree.get_root_id())
-            if revision_id == _mod_revision.NULL_REVISION:
-                wt.set_parent_trees([])
-            else:
-                wt.set_parent_trees([(revision_id, basis_tree)])
-            transform.build_tree(basis_tree, wt)
-        finally:
-            # Unlock in this order so that the unlock-triggers-flush in
-            # WorkingTree is given a chance to fire.
-            control_files.unlock()
-            wt.unlock()
-        return wt
-
-    def _initial_inventory(self):
-        return inventory.Inventory()
-
-    def open(self, a_bzrdir, _found=False):
-        """Return the WorkingTree object for a_bzrdir
-
-        _found is a private parameter, do not use it. It is used to indicate
-               if format probing has already been done.
-        """
-        if not _found:
-            # we are being called directly and must probe.
-            raise NotImplementedError
-        if not isinstance(a_bzrdir.transport, LocalTransport):
-            raise errors.NotLocalUrl(a_bzrdir.transport.base)
-        wt = self._open(a_bzrdir, self._open_control_files(a_bzrdir))
-        return wt
-
-    def _open(self, a_bzrdir, control_files):
-        """Open the tree itself.
-
-        :param a_bzrdir: the dir for the tree.
-        :param control_files: the control files for the tree.
-        """
-        return self._tree_class(a_bzrdir.root_transport.local_abspath('.'),
-                                _internal=True,
-                                _format=self,
-                                _bzrdir=a_bzrdir,
-                                _control_files=control_files)
-
-    def __str__(self):
-        return self.get_format_string()

=== modified file 'bzrlib/workingtree_4.py'
--- bzrlib/workingtree_4.py	2011-05-03 23:54:46 +0000
+++ bzrlib/workingtree_4.py	2011-04-21 00:41:42 +0000
@@ -34,7 +34,6 @@
 from bzrlib import (
     bzrdir,
     cache_utf8,
-    conflicts as _mod_conflicts,
     debug,
     dirstate,
     errors,
@@ -52,8 +51,6 @@
 from bzrlib.decorators import needs_read_lock, needs_write_lock
 from bzrlib.inventory import Inventory, ROOT_ID, entry_factory
 from bzrlib.lock import LogicalLockResult
-from bzrlib.lockable_files import LockableFiles
-from bzrlib.lockdir import LockDir
 from bzrlib.mutabletree import needs_tree_write_lock
 from bzrlib.osutils import (
     file_kind,
@@ -68,13 +65,13 @@
     InventoryTree,
     )
 from bzrlib.workingtree import (
-    InventoryWorkingTree,
     WorkingTree,
-    WorkingTreeFormat,
+    WorkingTree3,
+    WorkingTreeFormat3,
     )
 
 
-class DirStateWorkingTree(InventoryWorkingTree):
+class DirStateWorkingTree(WorkingTree3):
 
     def __init__(self, basedir,
                  branch,
@@ -131,10 +128,6 @@
             state.add(f, file_id, kind, None, '')
         self._make_dirty(reset_inventory=True)
 
-    def _get_check_refs(self):
-        """Return the references needed to perform a check of this tree."""
-        return [('trees', self.last_revision())]
-
     def _make_dirty(self, reset_inventory):
         """Make the tree state dirty.
 
@@ -192,7 +185,7 @@
 
     def _comparison_data(self, entry, path):
         kind, executable, stat_value = \
-            WorkingTree._comparison_data(self, entry, path)
+            WorkingTree3._comparison_data(self, entry, path)
         # it looks like a plain directory, but it's really a reference -- see
         # also kind()
         if (self._repo_supports_tree_reference and kind == 'directory'
@@ -204,7 +197,7 @@
     def commit(self, message=None, revprops=None, *args, **kwargs):
         # mark the tree as dirty post commit - commit
         # can change the current versioned list by doing deletes.
-        result = WorkingTree.commit(self, message, revprops, *args, **kwargs)
+        result = WorkingTree3.commit(self, message, revprops, *args, **kwargs)
         self._make_dirty(reset_inventory=True)
         return result
 
@@ -1380,7 +1373,7 @@
 class WorkingTree4(DirStateWorkingTree):
     """This is the Format 4 working tree.
 
-    This differs from WorkingTree by:
+    This differs from WorkingTree3 by:
      - Having a consolidated internal dirstate, stored in a
        randomly-accessible sorted file on disk.
      - Not having a regular inventory attribute.  One can be synthesized
@@ -1414,18 +1407,10 @@
         return views.PathBasedViews(self)
 
 
-class DirStateWorkingTreeFormat(WorkingTreeFormat):
+class DirStateWorkingTreeFormat(WorkingTreeFormat3):
 
     missing_parent_conflicts = True
 
-    _lock_class = LockDir
-    _lock_file_name = 'lock'
-
-    def _open_control_files(self, a_bzrdir):
-        transport = a_bzrdir.get_workingtree_transport(None)
-        return LockableFiles(transport, self._lock_file_name,
-                             self._lock_class)
-
     def initialize(self, a_bzrdir, revision_id=None, from_branch=None,
                    accelerator_tree=None, hardlink=False):
         """See WorkingTreeFormat.initialize().
@@ -1530,20 +1515,6 @@
         :param wt: the WorkingTree object
         """
 
-    def open(self, a_bzrdir, _found=False):
-        """Return the WorkingTree object for a_bzrdir
-
-        _found is a private parameter, do not use it. It is used to indicate
-               if format probing has already been done.
-        """
-        if not _found:
-            # we are being called directly and must probe.
-            raise NotImplementedError
-        if not isinstance(a_bzrdir.transport, LocalTransport):
-            raise errors.NotLocalUrl(a_bzrdir.transport.base)
-        wt = self._open(a_bzrdir, self._open_control_files(a_bzrdir))
-        return wt
-
     def _open(self, a_bzrdir, control_files):
         """Open the tree itself.
 

=== modified file 'doc/en/_static/en/bzr-en-quick-reference.pdf'
Binary files doc/en/_static/en/bzr-en-quick-reference.pdf and doc/en/_static/en/bzr-en-quick-reference.pdf differ
=== modified file 'doc/en/_static/en/bzr-en-quick-reference.png'
Binary files doc/en/_static/en/bzr-en-quick-reference.png and doc/en/_static/en/bzr-en-quick-reference.png differ
=== modified file 'doc/en/_static/en/bzr-en-quick-reference.svg'
--- doc/en/_static/en/bzr-en-quick-reference.svg	2011-04-20 10:25:40 +0000
+++ doc/en/_static/en/bzr-en-quick-reference.svg	2010-01-29 10:36:23 +0000
@@ -2,7 +2,7 @@
 <!-- Created with Inkscape (http://www.inkscape.org/) -->
 <svg
    xmlns:dc="http://purl.org/dc/elements/1.1/"
-   xmlns:cc="http://creativecommons.org/ns#"
+   xmlns:cc="http://web.resource.org/cc/"
    xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
    xmlns:svg="http://www.w3.org/2000/svg"
    xmlns="http://www.w3.org/2000/svg"
@@ -13,7 +13,7 @@
    height="744.09448"
    id="svg2766"
    sodipodi:version="0.32"
-   inkscape:version="0.46"
+   inkscape:version="0.45.1"
    version="1.0"
    sodipodi:docbase="/home/ian/bzr/repo.packs/bzr.quick-start-tweaks/doc/en/quick-reference"
    sodipodi:docname="quick-start-summary.svg"
@@ -363,7 +363,7 @@
              sodipodi:role="line"
              id="tspan2187"
              x="64.448624"
-             y="277.48495">bzr branch myproject newproject</tspan></text>
+             y="277.48495">bzr branch mp myproject</tspan></text>
         <text
            xml:space="preserve"
            style="font-size:12px;font-style:normal;font-variant:normal;font-weight:bold;font-stretch:normal;text-align:start;line-height:100%;writing-mode:lr-tb;text-anchor:start;fill:#333333;fill-opacity:1;fill-rule:nonzero;stroke:none;stroke-width:30.5;stroke-miterlimit:4;stroke-dasharray:none;stroke-dashoffset:0;stroke-opacity:1;font-family:Bitstream Vera Sans"
@@ -389,7 +389,7 @@
              sodipodi:role="line"
              id="tspan3406"
              x="64.448624"
-             y="308.44989">bzr checkout srcproject myproject</tspan></text>
+             y="308.44989">bzr checkout mp myproject</tspan></text>
         <text
            xml:space="preserve"
            style="font-size:12px;font-style:normal;font-variant:normal;font-weight:bold;font-stretch:normal;text-align:start;line-height:100%;writing-mode:lr-tb;text-anchor:start;fill:#333333;fill-opacity:1;fill-rule:nonzero;stroke:none;stroke-width:30.5;stroke-miterlimit:4;stroke-dasharray:none;stroke-dashoffset:0;stroke-opacity:1;font-family:Bitstream Vera Sans"
@@ -415,11 +415,11 @@
              id="tspan3424"
              sodipodi:role="line"
              x="64.448624"
-             y="341.88864">bzr checkout --lightweight \</tspan><tspan
+             y="341.88864">bzr checkout --lightweight mp \</tspan><tspan
              sodipodi:role="line"
              x="64.448624"
              y="352.96197"
-             id="tspan2780"> srcproject myproject</tspan></text>
+             id="tspan2780"> myproject</tspan></text>
         <text
            xml:space="preserve"
            style="font-size:12px;font-style:normal;font-variant:normal;font-weight:bold;font-stretch:normal;text-align:start;line-height:100%;writing-mode:lr-tb;text-anchor:start;fill:#333333;fill-opacity:1;fill-rule:nonzero;stroke:none;stroke-width:30.5;stroke-miterlimit:4;stroke-dasharray:none;stroke-dashoffset:0;stroke-opacity:1;font-family:Bitstream Vera Sans"
@@ -1329,7 +1329,7 @@
          sodipodi:role="line"
          id="tspan3411"
          x="146.57143"
-         y="97.808769">Quick Reference Card</tspan></text>
+         y="97.808769">Quick Start Card</tspan></text>
     <g
        id="g12314"
        transform="translate(17.946423,1.7472534)"

=== modified file 'doc/en/release-notes/bzr-2.4.txt'
--- doc/en/release-notes/bzr-2.4.txt	2011-05-04 23:53:19 +0000
+++ doc/en/release-notes/bzr-2.4.txt	2011-04-28 14:12:08 +0000
@@ -43,9 +43,6 @@
 .. Changes that may require updates in plugins or other code that uses
    bzrlib.
 
-* ``annotate_file`` has been deprecated in favor of
-  ``annotate_file_revision_tree``. (Jelmer Vernooij, #775598)
-
 Internals
 *********
 
@@ -174,10 +171,6 @@
 .. Changes that may require updates in plugins or other code that uses
    bzrlib.
 
-* ``Branch.update_revisions`` has been made private and should no
-  longer be used by external users. Use ``Branch.pull`` or ``Branch.push``
-  instead. (Jelmer Vernooij, #771765)
-
 * Commands now have an `invoked_as` attribute, showing the name under
   which they were called before alias expansion.
   (Martin Pool)
@@ -432,9 +425,6 @@
   ``RepositoryFormat.supports_leaving_lock`` flags have been added.
   (Jelmer Vernooij)
 
-* ``Branch.fetch`` implementations must now accept an optional
-  ``fetch_tags`` keyword argument. (Andrew Bennetts)
-
 * ``Branch.import_last_revision_info`` is deprecated.  Use the
   ``import_last_revision_info_and_tags`` method instead.
   (Andrew Bennetts)

=== removed directory 'po'
=== modified file 'setup.py'
--- setup.py	2011-05-05 13:03:12 +0000
+++ setup.py	2010-12-26 13:19:11 +0000
@@ -69,8 +69,7 @@
                                         'tests/ssl_certs/ca.crt',
                                         'tests/ssl_certs/server_without_pass.key',
                                         'tests/ssl_certs/server_with_pass.key',
-                                        'tests/ssl_certs/server.crt',
-                                        'locale/*/LC_MESSAGES/*.mo',
+                                        'tests/ssl_certs/server.crt'
                                        ]},
            }
 
@@ -153,10 +152,6 @@
     Generate bzr.1.
     """
 
-    sub_commands = build.sub_commands + [
-            ('build_mo', lambda _: True),
-            ]
-
     def run(self):
         build.run(self)
 
@@ -168,12 +163,8 @@
 ## Setup
 ########################
 
-from tools.build_mo import build_mo
-
 command_classes = {'install_scripts': my_install_scripts,
-                   'build': bzr_build,
-                   'build_mo': build_mo,
-                   }
+                   'build': bzr_build}
 from distutils import log
 from distutils.errors import CCompilerError, DistutilsPlatformError
 from distutils.extension import Extension

=== removed file 'tools/build_mo.py'
--- tools/build_mo.py	2011-05-05 12:53:46 +0000
+++ tools/build_mo.py	1970-01-01 00:00:00 +0000
@@ -1,125 +0,0 @@
-# -*- coding: utf-8 -*-
-#
-# Copyright (C) 2007 Lukáš Lalinský <lalinsky@gmail.com>
-# Copyright (C) 2007,2009 Alexander Belchenko <bialix@ukr.net>
-# Copyright 2011 Canonical Ltd.
-#
-# This program is free software; you can redistribute it and/or
-# modify it under the terms of the GNU General Public License
-# as published by the Free Software Foundation; either version 2
-# of the License, or (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-# This code is bring from bzr-explorer and modified for bzr.
-
-"""build_mo command for setup.py"""
-
-from distutils import log
-from distutils.command.build import build
-from distutils.core import Command
-from distutils.dep_util import newer
-from distutils.spawn import find_executable
-import os
-import re
-
-import msgfmt
-
-class build_mo(Command):
-    """Subcommand of build command: build_mo"""
-
-    description = 'compile po files to mo files'
-
-    # List of options:
-    #   - long name,
-    #   - short name (None if no short name),
-    #   - help string.
-    user_options = [('build-dir=', 'd', 'Directory to build locale files'),
-                    ('output-base=', 'o', 'mo-files base name'),
-                    ('source-dir=', None, 'Directory with sources po files'),
-                    ('force', 'f', 'Force creation of mo files'),
-                    ('lang=', None, 'Comma-separated list of languages '
-                                    'to process'),
-                   ]
-
-    boolean_options = ['force']
-
-    def initialize_options(self):
-        self.build_dir = None
-        self.output_base = None
-        self.source_dir = None
-        self.force = None
-        self.lang = None
-
-    def finalize_options(self):
-        self.set_undefined_options('build', ('force', 'force'))
-        self.prj_name = self.distribution.get_name()
-        if self.build_dir is None:
-            self.build_dir = 'bzrlib/locale'
-        if not self.output_base:
-            self.output_base = self.prj_name or 'messages'
-        if self.source_dir is None:
-            self.source_dir = 'po'
-        if self.lang is None:
-            if self.prj_name:
-                re_po = re.compile(r'^(?:%s-)?([a-zA-Z_]+)\.po$' % self.prj_name)
-            else:
-                re_po = re.compile(r'^([a-zA-Z_]+)\.po$')
-            self.lang = []
-            for i in os.listdir(self.source_dir):
-                mo = re_po.match(i)
-                if mo:
-                    self.lang.append(mo.group(1))
-        else:
-            self.lang = [i.strip() for i in self.lang.split(',') if i.strip()]
-
-    def run(self):
-        """Run msgfmt for each language"""
-        if not self.lang:
-            return
-
-        if 'en' in self.lang:
-            if find_executable('msginit') is None:
-                log.warn("GNU gettext msginit utility not found!")
-                log.warn("Skip creating English PO file.")
-            else:
-                log.info('Creating English PO file...')
-                pot = (self.prj_name or 'messages') + '.pot'
-                if self.prj_name:
-                    en_po = '%s-en.po' % self.prj_name
-                else:
-                    en_po = 'en.po'
-                self.spawn(['msginit',
-                    '--no-translator',
-                    '-l', 'en',
-                    '-i', os.path.join(self.source_dir, pot),
-                    '-o', os.path.join(self.source_dir, en_po),
-                    ])
-
-        basename = self.output_base
-        if not basename.endswith('.mo'):
-            basename += '.mo'
-
-        po_prefix = ''
-        if self.prj_name:
-            po_prefix = self.prj_name + '-'
-        for lang in self.lang:
-            po = os.path.join('po', lang + '.po')
-            if not os.path.isfile(po):
-                po = os.path.join('po', po_prefix + lang + '.po')
-            dir_ = os.path.join(self.build_dir, lang, 'LC_MESSAGES')
-            self.mkpath(dir_)
-            mo = os.path.join(dir_, basename)
-            if self.force or newer(po, mo):
-                log.info('Compile: %s -> %s' % (po, mo))
-                msgfmt.make(po,  mo)
-
-
-build.sub_commands.insert(0, ('build_mo', None))

=== removed file 'tools/msgfmt.py'
--- tools/msgfmt.py	2011-05-05 12:53:46 +0000
+++ tools/msgfmt.py	1970-01-01 00:00:00 +0000
@@ -1,208 +0,0 @@
-#! /usr/bin/env python
-# -*- coding: utf-8 -*-
-# Written by Martin v. Lowis <loewis@informatik.hu-berlin.de>
-
-# This script is copied from Python/Tools/i18n/msgfmt.py
-# It licensed under PSF license which compatible with GPL.
-#
-# ChangeLog
-# * Convert encoding from iso-8859-1 to utf-8
-# * Fix http://bugs.python.org/issue9741
-
-"""Generate binary message catalog from textual translation description.
-
-This program converts a textual Uniforum-style message catalog (.po file) into
-a binary GNU catalog (.mo file).  This is essentially the same function as the
-GNU msgfmt program, however, it is a simpler implementation.
-
-Usage: msgfmt.py [OPTIONS] filename.po
-
-Options:
-    -o file
-    --output-file=file
-        Specify the output file to write to.  If omitted, output will go to a
-        file named filename.mo (based off the input file name).
-
-    -h
-    --help
-        Print this message and exit.
-
-    -V
-    --version
-        Display version information and exit.
-"""
-
-import sys
-import os
-import getopt
-import struct
-import array
-
-__version__ = "1.1"
-
-MESSAGES = {}
-
-
-def usage(code, msg=''):
-    print >> sys.stderr, __doc__
-    if msg:
-        print >> sys.stderr, msg
-    sys.exit(code)
-
-
-def add(id, str, fuzzy):
-    "Add a non-fuzzy translation to the dictionary."
-    global MESSAGES
-    if not fuzzy and str:
-        MESSAGES[id] = str
-
-
-def generate():
-    "Return the generated output."
-    global MESSAGES
-    keys = MESSAGES.keys()
-    # the keys are sorted in the .mo file
-    keys.sort()
-    offsets = []
-    ids = strs = ''
-    for id in keys:
-        # For each string, we need size and file offset.  Each string is NUL
-        # terminated; the NUL does not count into the size.
-        offsets.append((len(ids), len(id), len(strs), len(MESSAGES[id])))
-        ids += id + '\0'
-        strs += MESSAGES[id] + '\0'
-    output = ''
-    # The header is 7 32-bit unsigned integers.  We don't use hash tables, so
-    # the keys start right after the index tables.
-    # translated string.
-    keystart = 7*4+16*len(keys)
-    # and the values start after the keys
-    valuestart = keystart + len(ids)
-    koffsets = []
-    voffsets = []
-    # The string table first has the list of keys, then the list of values.
-    # Each entry has first the size of the string, then the file offset.
-    for o1, l1, o2, l2 in offsets:
-        koffsets += [l1, o1+keystart]
-        voffsets += [l2, o2+valuestart]
-    offsets = koffsets + voffsets
-    output = struct.pack("Iiiiiii",
-                         0x950412deL,       # Magic
-                         0,                 # Version
-                         len(keys),         # # of entries
-                         7*4,               # start of key index
-                         7*4+len(keys)*8,   # start of value index
-                         0, 0)              # size and offset of hash table
-    output += array.array("i", offsets).tostring()
-    output += ids
-    output += strs
-    return output
-
-
-def make(filename, outfile):
-    # Fix http://bugs.python.org/issue9741
-    global MESSAGES
-    MESSAGES.clear()
-    ID = 1
-    STR = 2
-
-    # Compute .mo name from .po name and arguments
-    if filename.endswith('.po'):
-        infile = filename
-    else:
-        infile = filename + '.po'
-    if outfile is None:
-        outfile = os.path.splitext(infile)[0] + '.mo'
-
-    try:
-        lines = open(infile).readlines()
-    except IOError, msg:
-        print >> sys.stderr, msg
-        sys.exit(1)
-
-    section = None
-    fuzzy = 0
-
-    # Parse the catalog
-    lno = 0
-    for l in lines:
-        lno += 1
-        # If we get a comment line after a msgstr, this is a new entry
-        if l[0] == '#' and section == STR:
-            add(msgid, msgstr, fuzzy)
-            section = None
-            fuzzy = 0
-        # Record a fuzzy mark
-        if l[:2] == '#,' and 'fuzzy' in l:
-            fuzzy = 1
-        # Skip comments
-        if l[0] == '#':
-            continue
-        # Now we are in a msgid section, output previous section
-        if l.startswith('msgid'):
-            if section == STR:
-                add(msgid, msgstr, fuzzy)
-            section = ID
-            l = l[5:]
-            msgid = msgstr = ''
-        # Now we are in a msgstr section
-        elif l.startswith('msgstr'):
-            section = STR
-            l = l[6:]
-        # Skip empty lines
-        l = l.strip()
-        if not l:
-            continue
-        # XXX: Does this always follow Python escape semantics?
-        l = eval(l)
-        if section == ID:
-            msgid += l
-        elif section == STR:
-            msgstr += l
-        else:
-            print >> sys.stderr, 'Syntax error on %s:%d' % (infile, lno), \
-                  'before:'
-            print >> sys.stderr, l
-            sys.exit(1)
-    # Add last entry
-    if section == STR:
-        add(msgid, msgstr, fuzzy)
-
-    # Compute output
-    output = generate()
-
-    try:
-        open(outfile,"wb").write(output)
-    except IOError,msg:
-        print >> sys.stderr, msg
-
-
-def main():
-    try:
-        opts, args = getopt.getopt(sys.argv[1:], 'hVo:',
-                                   ['help', 'version', 'output-file='])
-    except getopt.error, msg:
-        usage(1, msg)
-
-    outfile = None
-    # parse options
-    for opt, arg in opts:
-        if opt in ('-h', '--help'):
-            usage(0)
-        elif opt in ('-V', '--version'):
-            print >> sys.stderr, "msgfmt.py", __version__
-            sys.exit(0)
-        elif opt in ('-o', '--output-file'):
-            outfile = arg
-    # do it
-    if not args:
-        print >> sys.stderr, 'No input file given'
-        print >> sys.stderr, "Try `msgfmt --help' for more information."
-        return
-
-    for filename in args:
-        make(filename, outfile)
-
-
-if __name__ == '__main__':
-    main()

